@@ -6,7 +6,7 @@ import os
 from logging import info
 
 from portmod.config import get_config, set_config_value
-from portmod.config.profiles import profile_exists, set_profile
+from portmod.config.profiles import get_profile_path, profile_exists, set_profile
 from portmod.globals import env
 from portmod.prefix import add_prefix
 from portmod.prompt import prompt_bool, prompt_num, prompt_num_multi
@@ -17,7 +17,7 @@ from portmod.sync import sync
 from portmodlib.colour import bright
 from portmodlib.l10n import l10n
 
-from .select import add_prefix_repo, get_profile, list_profiles, list_repos
+from .select import add_prefix_repo, list_profiles, list_repos
 
 
 def init(args):
@@ -34,7 +34,7 @@ def init(args):
             enabled = " ".join(get_config()["REPOS"])
             print()
             print(f'    REPOS = "{enabled}"')
-            print(f'    profile = "{get_profile()}"')
+            print(f'    profile = "{get_profile_path()}"')
             print()
             if prompt_bool(l10n("existing-configuration-prompt")):
                 return
