@@ -32,6 +32,7 @@ from portmod.repo.metadata import (
     license_exists,
 )
 from portmodlib.atom import Atom, InvalidAtom, UnqualifiedAtom
+from portmodlib.colour import green
 from portmodlib.l10n import l10n
 from portmodlib.log import add_logging_arguments, init_logger
 from portmodlib.parsers.list import read_list
@@ -46,25 +47,27 @@ from .pybuild import pybuild_manifest, pybuild_validate
 
 
 def scan_package_dir(path: str, err: Callable[[str], None]):
+    root = os.path.dirname(os.path.dirname(path))
     cpn = os.path.join(os.path.basename(os.path.dirname(path)), os.path.basename(path))
-    if Atom(os.path.basename(cpn)).PV is not None:
+    if Atom(os.path.basename(cpn)).version is not None:
         err(f"Package name {cpn} must not end in a version")
 
     for file in glob.glob(os.path.join(path, "*.pybuild")):
-        debug(f"Scanning {file}")
+        relative_path = os.path.relpath(file, start=root)
+        debug(f"Scanning {relative_path}")
         dir_name = os.path.basename(path)
         file_name = Atom(os.path.splitext(os.path.basename(file))[0]).PN
         if dir_name != file_name:
             err(
-                f"The package name in filename {file} should match its parent directory's name!"
+                f"The package name in filename {relative_path} should match its parent directory's name!"
             )
 
         try:
             pybuild_validate(file)
         except SandboxedError as e:
-            err(f"{e}")
+            err(f"Error validating file {green(relative_path)}: {e}")
         except Exception as e:
-            err(f"{e}")
+            err(f"Error validating file {green(relative_path)}: {e}")
 
 
 def scan_category_metadata(path: str, err: Callable[[str], None]):
@@ -325,15 +328,15 @@ def commit_message(args, repo_root: str, err: Callable[[str], None]):
                 new = get_atom_from_path(diff.b_path)
 
             if diff.deleted_file:
-                message = f"{old.CPN}: Removed version {old.PV}"
+                message = f"{old.CPN}: Removed version {old.version}"
                 if check_initial_message(message, initial_message):
                     message += f"\n\n{initial_message}"
             elif diff.new_file:
-                message = f"{new.CPN}: Added version {new.PV}"
+                message = f"{new.CPN}: Added version {new.version}"
                 if check_initial_message(message, initial_message):
                     message += f"\n\n{initial_message}"
-            elif diff.renamed_file and old.PV != new.PV:
-                message = f"{new.CPN}: Updated to version {new.PV}"
+            elif diff.renamed_file and old.version != new.version:
+                message = f"{new.CPN}: Updated to version {new.version}"
                 if check_initial_message(message, initial_message):
                     message += f"\n\n{initial_message}"
             else:
@@ -372,7 +375,7 @@ def scan(args, repo_root: str, err: Callable[[str], None]):
 
         for file in git.Git().diff(args.diff, name_only=True).splitlines():
             scan_file(os.path.join(repo_root, file), repo_root, err)
-            if file.endswith(".pybuild"):
+            if file.endswith(".pybuild") and os.path.exists(file):
                 scan_sources(file, err)
 
         for commit in git.Git().log("HEAD", "^" + args.diff, pretty="%H").splitlines():
@@ -521,7 +524,11 @@ def test_install_cli(args, repo_root, _err):
             destroy(SimpleNamespace(remove_config=True, preserve_root=False))
 
 
-def get_parser():
+def get_doc_parser():
+    return get_parser(True)
+
+
+def get_parser(doc=False):
     common = argparse.ArgumentParser(add_help=False)
     add_logging_arguments(common)
     common.add_argument("--debug", help=l10n("merge-debug-help"), action="store_true")
@@ -530,18 +537,21 @@ def get_parser():
         description="Quality assurance program for the package repository",
         parents=[common],
     )
+
+    parents = [] if doc else [common]
+
     subparsers = parser.add_subparsers()
     manifest_parser = subparsers.add_parser(
-        "manifest", help="Produces Manifest files", parents=[common]
+        "manifest", help="Produces Manifest files", parents=parents
     )
     scan_parser = subparsers.add_parser(
-        "scan", help="QA Checks package repositories", parents=[common]
+        "scan", help="QA Checks package repositories", parents=parents
     )
     commit_msg_parser = subparsers.add_parser(
         "commit-msg",
         help="Produces a commit message using the working directory. "
         "Designed to be used as a git commit-msg hook",
-        parents=[common],
+        parents=parents,
     )
     commit_msg_parser.add_argument(
         "initial_message",
@@ -572,7 +582,7 @@ def get_parser():
         nargs="*",
     )
     test_install_parser = subparsers.add_parser(
-        "test-install", help="Tests package installation", parents=[common]
+        "test-install", help="Tests package installation", parents=parents
     )
     test_install_parser.add_argument("arch", help="Architecture to test")
     test_install_parser.add_argument(
