@@ -154,6 +154,11 @@ def get_parser(
     group = parser.add_mutually_exclusive_group()
     group.add_argument("--version", help=l10n("version-help"), action="store_true")
 
+    # For generic parser, don't repeat common arguments. While technically they
+    # can be included everywhere, the docs blow up in size if they are listed
+    # by each subcommand.
+    parents = [] if generic else [common]
+
     subparsers = parser.add_subparsers(dest="subcommand_name")
 
     if (
@@ -170,7 +175,7 @@ def get_parser(
                 prefix,
                 help=l10n("prefix-help", prefix=prefix),
                 description=l10n("prefix-help", prefix=prefix),
-                parents=[common],
+                parents=parents,
             )
             prefix_parsers_list.append(
                 prefix_parser.add_subparsers(dest="prefix_subcommand_name")
@@ -198,59 +203,59 @@ def get_parser(
         prefix = subcommand
 
         prefix_parser = subparsers.add_parser(
-            prefix, help=l10n("prefix-help", prefix=prefix), parents=[common]
+            prefix, help=l10n("prefix-help", prefix=prefix), parents=parents
         )
         prefix_parsers = prefix_parser.add_subparsers(dest="prefix_subcommand_name")
         prefix_parser.set_defaults(func=lambda args: prefix_parser.print_help())
         if prefix_subcommand == "merge":
-            add_merge_parser(prefix_parsers, [common])
+            add_merge_parser(prefix_parsers, parents)
         elif prefix_subcommand == "search":
-            add_search_parser(prefix_parsers, [common])
+            add_search_parser(prefix_parsers, parents)
         elif prefix_subcommand == "select":
-            add_select_parser(prefix_parsers, [common])
+            add_select_parser(prefix_parsers, parents)
         elif prefix_subcommand == "query":
-            add_query_parser(prefix_parsers, [common])
+            add_query_parser(prefix_parsers, parents)
         elif prefix_subcommand == "use":
-            add_use_parser(prefix_parsers, [common])
+            add_use_parser(prefix_parsers, parents)
         elif prefix_subcommand == "info":
-            add_info_parser(prefix_parsers, [common])
+            add_info_parser(prefix_parsers, parents)
         elif prefix_subcommand == "validate":
             prefix_parsers.add_parser(
-                "validate", help=l10n("validate-help"), parents=[common]
+                "validate", help=l10n("validate-help"), parents=parents
             ).set_defaults(func=validate)
         elif prefix_subcommand == "destroy":
-            add_destroy_parser(prefix_parsers, [common])
+            add_destroy_parser(prefix_parsers, parents)
         elif prefix_subcommand == "run":
-            add_run_parser(prefix_parsers, [common])
+            add_run_parser(prefix_parsers, parents)
         elif prefix_subcommand == "cfg-update":
-            add_cfg_update_parser(prefix_parsers, [common])
+            add_cfg_update_parser(prefix_parsers, parents)
     elif subcommand == "mirror":
-        add_mirror_parser(subparsers, [common])
+        add_mirror_parser(subparsers, parents)
     elif subcommand is not None and subcommand in get_prefixes() and generic:
         prefix = subcommand
         # Add all the parsers. This is relatively slow, but necessary for sphinx-argparse
         prefix_parser = subparsers.add_parser(
-            prefix, help=l10n("prefix-help", prefix=prefix), parents=[common]
+            prefix, help=l10n("prefix-help", prefix=prefix), parents=parents
         )
         prefix_parsers = prefix_parser.add_subparsers(dest="prefix_subcommand_name")
         prefix_parser.set_defaults(func=lambda args: prefix_parser.print_help())
-        add_merge_parser(prefix_parsers, [common])
-        add_search_parser(prefix_parsers, [common])
-        add_select_parser(prefix_parsers, [common])
-        add_query_parser(prefix_parsers, [common])
-        add_use_parser(prefix_parsers, [common])
-        add_info_parser(prefix_parsers, [common])
+        add_merge_parser(prefix_parsers, parents)
+        add_search_parser(prefix_parsers, parents)
+        add_select_parser(prefix_parsers, parents)
+        add_query_parser(prefix_parsers, parents)
+        add_use_parser(prefix_parsers, parents)
+        add_info_parser(prefix_parsers, parents)
         prefix_parsers.add_parser(
-            "validate", help=l10n("validate-help"), parents=[common]
+            "validate", help=l10n("validate-help"), parents=parents
         ).set_defaults(func=validate)
-        add_destroy_parser(prefix_parsers, [common])
-        add_run_parser(prefix_parsers, [common])
-        add_cfg_update_parser(prefix_parsers, [common])
+        add_destroy_parser(prefix_parsers, parents)
+        add_run_parser(prefix_parsers, parents)
+        add_cfg_update_parser(prefix_parsers, parents)
 
-        add_mirror_parser(subparsers, [common])
+        add_mirror_parser(subparsers, parents)
 
-    add_init_parser(subparsers, parents=[common])
-    add_sync_parser(subparsers, parents=[common])
+    add_init_parser(subparsers, parents=parents)
+    add_sync_parser(subparsers, parents=parents)
     return parser
 
 
