@@ -16,11 +16,14 @@ def add_mirror_parser(subparsers, parents):
     parser.add_argument(
         "mirror", metavar=l10n("directory-placeholder"), help=l10n("mirror-dir-help")
     )
+    parser.add_argument(
+        "repo", metavar=l10n("repo-placeholder"), help=l10n("mirror-repo-help")
+    )
 
     def mirror_main(args):
         if args.mirror:
             os.makedirs(args.mirror, exist_ok=True)
-            for mod in load_all():
+            for mod in load_all(repo_name=args.repo):
                 if mirrorable(mod):
                     try:
                         for source in download_mod(mod, set(), matchall=True):
