@@ -347,7 +347,7 @@ def add_query_parser(subparsers, parents):
         argument(
             "atom",
             metavar=l10n("atom-placeholder"),
-            help=l10n("package-depgraph-atom-help"),
+            help=l10n("query-depgraph-atom-help"),
         ),
         argument("--depth", type=int, help=l10n("query-depgraph-depth-help")),
         parent=subparsers,
@@ -360,7 +360,7 @@ def add_query_parser(subparsers, parents):
 
         for mod in modlist:
             print(" * " + l10n("query-depgraph-depgraph", atom=mod.ATOM))
-            max_depth = print_depgraph(mod, 1, args.depth or 10)
+            max_depth = print_depgraph(mod, 1, args.depth or 10, set())
             print(" " + l10n("query-depgraph-max-depth") + f"({max_depth})")
             print()
 
