@@ -1,6 +1,7 @@
 # Copyright 2019-2021 Portmod Authors
 # Distributed under the terms of the GNU General Public License v3
 
+from portmod.globals import env
 from portmod.lock import exclusive_lock
 from portmod.merge import configure
 from portmod.prompt import prompt_num_multi
@@ -17,13 +18,14 @@ def search_main(args):
     )
     display_search_results(pkgs, numbers=True)
 
-    try:
-        selection = selection_prompt([pkg.cpn for pkg in pkgs])
-    except EOFError:
-        return
-    if selection:
-        with exclusive_lock():
-            configure(selection)
+    if env.INTERACTIVE:
+        try:
+            selection = selection_prompt([pkg.cpn for pkg in pkgs])
+        except EOFError:
+            return
+        if selection:
+            with exclusive_lock():
+                configure(selection)
 
 
 def selection_prompt(atoms):
