@@ -12,12 +12,18 @@ from logging import info
 from typing import List, Optional
 
 from portmod.config import get_config, set_config_value
-from portmod.config.profiles import get_profile_path, set_profile
+from portmod.config.profiles import (
+    get_profile_name,
+    get_profile_path,
+    profile_link,
+    profile_parents,
+    set_profile,
+)
 from portmod.globals import env
 from portmod.modules import add_parsers
 from portmod.news import add_news_parsers
 from portmod.prompt import display_num_list
-from portmod.repo import RemoteRepo, has_repo
+from portmod.repo import RemoteRepo, get_repo_name, has_repo
 from portmod.repo.metadata import get_profiles
 from portmod.repos import add_repo, get_remote_repos, get_repos
 from portmod.sync import sync
@@ -27,13 +33,6 @@ from portmodlib.l10n import l10n
 from .error import InputException
 
 
-def get_profile():
-    linkpath = os.path.join(env.prefix().CONFIG_DIR, "profile")
-    if os.path.exists(linkpath) and os.path.islink(linkpath):
-        return os.readlink(linkpath).split("profiles")[-1].lstrip(os.path.sep)
-    return None
-
-
 def list_profiles(arch: str) -> List[str]:
     """
     Prints a list of profiles
@@ -85,7 +84,7 @@ def list_repos(arch: str) -> List[RemoteRepo]:
 
 def add_prefix_repo(repo: str):
     enabled_repos = get_config()["REPOS"]
-    repo_name = get_repo_name(repo)
+    repo_name = get_repo_name_from_input(repo)
 
     if repo_name and repo_name not in enabled_repos:
         enabled_repos.add(repo_name)
@@ -96,7 +95,7 @@ def add_prefix_repo(repo: str):
     env.set_prefix(env.PREFIX_NAME)
 
 
-def get_repo_name(value: str) -> str:
+def get_repo_name_from_input(value: str) -> str:
     repos = list(get_remote_repos(env.prefix().ARCH).values())
     if value.isdigit():
         repo_name = repos[int(value)].name
@@ -120,6 +119,9 @@ def add_profile_parsers(subparsers, parents):
         "index", metavar=l10n("number-placeholder"), help=l10n("profile-number-help")
     )
     profile_show = profile_subparsers.add_parser("show", help=l10n("profile-show-help"))
+    profile_debug = profile_subparsers.add_parser(
+        "debug", help=l10n("profile-debug-help")
+    )
 
     def list_func(_args):
         list_profiles(env.prefix().ARCH)
@@ -133,12 +135,29 @@ def add_profile_parsers(subparsers, parents):
         set_profile(path)
 
     def show_func(_args):
-        linkpath = os.path.join(env.prefix().CONFIG_DIR, "profile")
-        print(bright(green(l10n("profile-current-symlink", path=linkpath))))
-        print(
-            "  "
-            + bright(os.readlink(linkpath).split("profiles")[-1].lstrip(os.path.sep))
-        )
+        print(bright(green(l10n("profile-current-name", path=profile_link()))))
+        try:
+            print(
+                "  "
+                + bright(get_profile_name())
+                + f" ({get_repo_name(get_profile_path())})"
+            )
+        except FileNotFoundError:
+            print("  Profile is not set")
+
+    def debug_func(_args):
+        print("Full path of profile:")
+        print("  " + get_profile_path())
+
+        print("Inherited profile directories:")
+        for path in profile_parents():
+            print("  ", path)
+
+        print("Files in the profile:")
+        for path in profile_parents():
+            for file in os.listdir(path):
+                if file != "parent":
+                    print("  ", os.path.join(path, file))
 
     def profile_help(args):
         profile.print_help()
@@ -147,6 +166,7 @@ def add_profile_parsers(subparsers, parents):
     profile_list.set_defaults(func=list_func)
     profile_set.set_defaults(func=set_func)
     profile_show.set_defaults(func=show_func)
+    profile_debug.set_defaults(func=debug_func)
 
 
 def add_repo_parser(subparsers, parents):
