@@ -7,6 +7,7 @@ from logging import error, warning
 from portmod.globals import env
 from portmod.loader import load_installed_pkg
 from portmod.parsers.manifest import ManifestEntry
+from portmod.vdb import vdb_path
 from portmodlib.atom import Atom
 from portmodlib.l10n import l10n
 
@@ -21,7 +22,7 @@ def get_packages(path: str):
 
 def validate(args):
     # Check that mods in the DB correspond to mods in the mods directory
-    for category, package in get_packages(env.prefix().INSTALLED_DB):
+    for category, package in get_packages(vdb_path()):
         # Check that pybuild can be loaded
         pkg = load_installed_pkg(Atom(f"{category}/{package}"))
         if not pkg:
