@@ -39,7 +39,7 @@ from portmod.transactions import (
     UseDep,
     generate_transactions,
 )
-from portmodlib.atom import Atom, FQAtom, QualifiedAtom, atom_sat
+from portmodlib.atom import Atom, FQAtom, atom_sat
 from portmodlib.l10n import l10n
 
 from .formula import Formula, Target, add_masked, cond_flagstr, fstr, generate_formula
@@ -237,7 +237,7 @@ def resolve(
 
         # Raise exception if mod name is ambiguous (exists in multiple categories)
         if not all(mod.ATOM.C == modlist[0].ATOM.C for mod in modlist):
-            raise AmbiguousAtom(atom, [mod.ATOM for mod in modlist])
+            raise AmbiguousAtom(atom, {mod.CPN for mod in modlist})
 
         if not modlist:
             if atom in set(selected):
@@ -284,10 +284,6 @@ def resolve(
         pkg = load_pkg(atom)[0]
         selected_cpn.add(pkg.CPN)
 
-    selected_from_sets: Set[QualifiedAtom] = set()
-    for set_name in selected_sets:
-        selected_from_sets |= {QualifiedAtom(atom) for atom in get_set(set_name)}
-
     # Hard clauses
 
     # The explicitly passed packages are aleays handled in deep mode
