@@ -1,6 +1,9 @@
 # Copyright 2019-2021 Portmod Authors
 # Distributed under the terms of the GNU General Public License v3
 
+from __future__ import annotations
+
+from abc import ABC, abstractmethod
 from collections import defaultdict
 from logging import warning
 from types import SimpleNamespace
@@ -55,7 +58,7 @@ class Formula:
     __stringcache: Dict[int, Token] = {}
     __variabledesc: Dict[Token, str] = {}
 
-    class Clause:
+    class Clause(ABC):
         """Generic clause type"""
 
         def __init__(self, clause: Iterable[Token], source):
@@ -71,13 +74,11 @@ class Formula:
             self.intclause = list(map(Formula.getnum, self.clause))
             return self
 
-        def sourceatom(self) -> Optional[Atom]:
-            return None
-
+        @abstractmethod
         def colourless(self) -> str:
             ...
 
-        def blocks(self, model: Set[Token], clause: "Formula.Clause") -> bool:
+        def blocks(self, _model: Set[Token], _clause: Formula.Clause) -> bool:
             return False
 
     class MetaClause(Clause):
@@ -96,14 +97,12 @@ class Formula:
             self.atmost = atmost
             self.requirements: Set[Token] = set()
 
+        def colourless(self) -> str:
+            return str(self)
+
         def __str__(self):
             return f"{self.source} - {self.desc}"
 
-        def sourceatom(self) -> Optional[Atom]:
-            if isinstance(self.source, Atom):
-                return self.source
-            return None
-
     class DepClause(Clause):
         def __init__(self, source: str, clause: Iterable[Token], dependency: Atom):
             super().__init__(clause, source)
@@ -115,7 +114,7 @@ class Formula:
         def colourless(self):
             return f"{self.dependency}: required by {self.source}"
 
-        def blocks(self, model: Set[Token], clause: "Formula.Clause") -> bool:
+        def blocks(self, model: Set[Token], clause: Formula.Clause) -> bool:
             if isinstance(clause, Formula.BlockerClause):
                 if atom_sat(self.dependency, clause.blocked) and all(
                     req in model for req in self.requirements
@@ -124,11 +123,6 @@ class Formula:
 
             return False
 
-        def sourceatom(self) -> Optional[Atom]:
-            if isinstance(self.source, Atom):
-                return self.source
-            return None
-
     class BlockerClause(Clause):
         def __init__(self, source: str, clause: Iterable[Token], blocked: Atom):
             super().__init__(clause, source)
@@ -140,7 +134,7 @@ class Formula:
         def colourless(self):
             return f"{self.blocked}: blocked by {self.source}"
 
-        def blocks(self, model: Set[Token], clause: "Formula.Clause") -> bool:
+        def blocks(self, model: Set[Token], clause: Formula.Clause) -> bool:
             if isinstance(clause, Formula.DepClause):
                 if atom_sat(self.blocked, clause.dependency) and all(
                     req in model for req in self.requirements
@@ -149,11 +143,6 @@ class Formula:
 
             return False
 
-        def sourceatom(self) -> Optional[Atom]:
-            if isinstance(self.source, Atom):
-                return self.source
-            return None
-
     class UseDepClause(Clause):
         def __init__(
             self, source: str, clause: Iterable[Token], depatom: Atom, flag: FlagToken
@@ -170,7 +159,7 @@ class Formula:
         def colourless(self):
             return f"{self.depatom}[{self.flag}]: required by {self.source}"
 
-        def blocks(self, model: Set[Token], clause: "Formula.Clause") -> bool:
+        def blocks(self, model: Set[Token], clause: Formula.Clause) -> bool:
             if isinstance(clause, Formula.UseDepClause):
                 if (
                     atom_sat(self.depatom, clause.depatom)
@@ -237,7 +226,7 @@ class Formula:
                     f"the larger clause {parent}"
                 )
 
-        def blocks(self, model: Set[Token], clause: "Formula.Clause") -> bool:
+        def blocks(self, model: Set[Token], clause: Formula.Clause) -> bool:
             if isinstance(clause, Formula.UseDepClause):
                 if (
                     atom_sat(self.atom, clause.depatom)
@@ -255,9 +244,6 @@ class Formula:
 
             return False
 
-        def sourceatom(self) -> Optional[Atom]:
-            return self.atom
-
     def __init__(self):
         self.clauses = []
         self.atoms: Dict[QualifiedAtom, Set[FQAtom]] = defaultdict(set)
@@ -297,7 +283,7 @@ class Formula:
     def get_variable_desc(cls, var: Token) -> str:
         return cls.__variabledesc[var]
 
-    def merge(self, other: "Formula"):
+    def merge(self, other: Formula):
         self.clauses.extend(other.clauses)
         self.flags |= other.flags
         for atom, values in other.atoms.items():
