@@ -140,25 +140,31 @@ def set_config_value(key: str, value: str, path: Optional[str] = None) -> Option
         path = env.prefix().CONFIG
 
     old = None
-    with open(path, "r") as file:
-        node = RedBaron(file.read())
+    string = '"' + value + '"'
+    new_line = f"{key} = {string}"
+    if os.path.exists(path):
+        with open(path, "r") as file:
+            node = RedBaron(file.read())
 
-        string = '"' + value + '"'
+            for elem in node:
+                if (
+                    isinstance(elem, AssignmentNode)
+                    and isinstance(elem.target, NameNode)
+                    and elem.target.value == key
+                ):
+                    old = elem.value
+                    elem.value = string
 
-        for elem in node:
-            if (
-                isinstance(elem, AssignmentNode)
-                and isinstance(elem.target, NameNode)
-                and elem.target.value == key
-            ):
-                old = elem.value
-                elem.value = string
-
-        if not old:
-            node.append(f"{key} = {string}")
+            if not old and node:
+                node.append(new_line)
+            elif not node:
+                node = RedBaron(new_line)
 
+            with open(path, "w") as file:
+                file.write(node.dumps())
+    else:
         with open(path, "w") as file:
-            file.write(node.dumps())
+            file.write(new_line)
 
     get_config.cache_clear()
     return old
