@@ -5,7 +5,6 @@ Module that interacts with the python-based portmod.conf config file
 """
 
 import os
-import sys
 from copy import deepcopy
 from textwrap import fill
 from typing import Any, Dict, Optional
@@ -38,7 +37,7 @@ __OVERRIDE_KEYS = {
     "VFS",
 }
 
-__USER_ONLY_VARIABLES = {"TMP", "TMPDIR", "TEMP", "_SANDBOX_PERMISSIONS", "MERGE_TOOL"}
+__USER_ONLY_VARIABLES = {"TMP", "TMPDIR", "TEMP", "SANDBOX_PERMISSIONS", "MERGE_TOOL"}
 
 
 def _comment_wrap(text: str) -> str:
@@ -105,9 +104,6 @@ def read_config(path: str, old_config: Dict[str, Any], *, user: bool = False) ->
     with open(path, "r", encoding=encoding) as file:
         config = file.read()
 
-    if sys.platform == "win32":
-        config = config.replace("\\", "\\\\")
-
     byte_code = compile_restricted(config, filename=path, mode="exec", policy=Policy)
 
     glob = deepcopy(MINIMAL_GLOBALS)
