@@ -23,6 +23,9 @@ def select_texture_size(texture_sizes: List[int]) -> Optional[int]:
     if not texture_sizes:
         return None
 
+    if len(texture_sizes) == 1:
+        return texture_sizes[0]
+
     assert match
     operator = match.group("OP")
     comparison = match.group("G")
