@@ -4,22 +4,31 @@
 import os
 import re
 import sys
-from functools import lru_cache
 from logging import info, warning
-from typing import Callable, Generator, Mapping, Optional, Set, Tuple, cast
+from typing import (
+    Callable,
+    Dict,
+    Generator,
+    Mapping,
+    Optional,
+    Sequence,
+    Set,
+    Tuple,
+    cast,
+)
 
-from portmod.functools import prefix_aware_cache
+from portmod.functools import install_cache, prefix_aware_cache
 from portmod.globals import env
 from portmod.parsers.flags import add_flag, collapse_flags, get_flags, remove_flag
 from portmod.pybuild import Pybuild
 from portmod.repo import get_repo
 from portmod.repo.metadata import get_use_flag_atom_aliases
-from portmod.repo.profiles import profile_parents
 from portmodlib.atom import Atom, QualifiedAtom
 from portmodlib.l10n import l10n
 from portmodlib.usestr import use_reduce
 
 from . import get_config, read_config, set_config_value
+from .profiles import profile_parents
 from .textures import select_texture_size
 
 
@@ -33,103 +42,14 @@ class InvalidFlag(Exception):
             super().__init__(l10n("invalid-flag", flag=flag))
 
 
-@lru_cache(maxsize=None)
-def get_use_expand_flags() -> Set[str]:
-    """Returns all currently enabled USE_EXPAND flags"""
-    flags = set()
-    for use in get_config().get("USE_EXPAND", []):
-        if not use.startswith("-"):
-            for flag in get_config().get(use, "").split():
-                flags.add(f"{use.lower()}_{flag}")
-    return flags
-
-
-def get_use_expand(pkg: Pybuild, use_expand: str) -> Tuple[Set[str], Set[str]]:
-    """
-    Returns the set of enabled flags for the given package and USE_EXPAND category
-    """
-    flags = {
-        re.sub(f"^{use_expand.lower()}_", "", flag)
-        for flag in pkg.IUSE_EFFECTIVE
-        if flag.startswith(f"{use_expand.lower()}_")
-    }
-    enabled_use = pkg.get_use()
-    enabled_expand = {
-        re.sub(f"^{use_expand}_", "", val, flags=re.IGNORECASE)
-        for val in enabled_use
-        if val.startswith(use_expand.lower() + "_")
-    }
-
-    return enabled_expand, flags - enabled_expand
-
-
 @prefix_aware_cache
-def get_user_global_use() -> Set[str]:
-    """Returns user-specified global use flags"""
-    global_use = cast(Set[str], read_config(env.prefix().CONFIG, {}).get("USE", set()))
-
-    # Also return global user-set USE_EXPAND values
-    for use in get_config().get("USE_EXPAND", []):
-        values = set(read_config(env.prefix().CONFIG, {}).get(use, "").split())
-        flags = {use.lower() + "_" + value for value in values}
-        global_use |= flags
-
-    return global_use
-
-
-@prefix_aware_cache
-def get_user_use(atom: Atom) -> Set[str]:
-    """Returns user-specified use flags for a given mod"""
-    use_file = os.path.join(env.prefix().CONFIG_DIR, "package.use")
-    if os.path.exists(use_file):
-        return get_flags(use_file, atom)
-
-    return set()
-
-
-def _iter_files(
-    directory: str, basename: Optional[str], suffix: str
-) -> Generator[str, None, None]:
-    if basename:
-        paths = [
-            ".".join([basename, suffix]),
-            ".".join([basename, sys.platform, suffix]),
-        ]
-    else:
-        paths = [".".join([suffix]), ".".join([sys.platform, suffix])]
-
-    for path in paths:
-        path = os.path.join(directory, path)
-        if os.path.exists(path):
-            yield path
-
-
-@prefix_aware_cache
-def get_forced_use(atom: Atom) -> Set[str]:
-    """Returns a list of forced use flags for the given mod"""
-    force: Set[str] = set()
-    for parent_dir in profile_parents():
-        for force_file in _iter_files(parent_dir, None, "use.force"):
-            flags = get_flags(force_file)
-            force = collapse_flags(force, flags)
-
-        for pkg_force_file in _iter_files(parent_dir, "package", "use.force"):
-            flags = get_flags(pkg_force_file, atom)
-            force = collapse_flags(force, flags)
-
-    return force
-
-
-@prefix_aware_cache
-def get_use(
+def _get_use_defaults(
     pkg: Pybuild, is_installed: Optional[Callable[[QualifiedAtom], bool]] = None
-) -> Tuple[Set[str], Set[str]]:
+) -> Set:
+    """
+    Returns a set of USE flags, each prepended with a plus, minus, or nothing,
     """
-    Returns a list of enabled and a list of disabled use flags
 
-    The disabled flag list only contains the flags which have been explicitly disabled.
-    Any flags missing from both lists should be considered implicitly disabled.
-    """
     from portmod.loader import load_installed_pkg
 
     if is_installed is None:
@@ -166,7 +86,43 @@ def get_use(
             and aliases[flag].CPN != pkg.CPN
         ):
             aliased_flags.add(flag)
-    defaults = collapse_flags(defaults, aliased_flags)
+    return collapse_flags(defaults, aliased_flags)
+
+
+@prefix_aware_cache
+def get_use_defaults(pkg: Pybuild) -> Dict[str, bool]:
+    """
+    Returns a dictionary containing the default states of the
+    given Pybuild's USE flags.
+    """
+
+    default_flags = _get_use_defaults(pkg)
+    defaults_dict: Dict[str, bool] = {}
+
+    # Default values in IUSE have the lowest priority
+    for flag in default_flags:
+        if flag.startswith("+"):
+            defaults_dict[flag[1:]] = True
+        elif flag.startswith("-"):
+            defaults_dict[flag[1:]] = False
+        else:
+            defaults_dict[flag] = False
+
+    return defaults_dict
+
+
+@install_cache
+def get_use(
+    pkg: Pybuild, is_installed: Optional[Callable[[QualifiedAtom], bool]] = None
+) -> Tuple[Set[str], Set[str]]:
+    """
+    Returns a list of enabled and a list of disabled use flags
+
+    The disabled flag list only contains the flags which have been explicitly disabled.
+    Any flags missing from both lists should be considered implicitly disabled.
+    """
+
+    defaults = _get_use_defaults(pkg, is_installed)
 
     GLOBAL_USE = get_config().get("USE", [])
     use: Set[str] = get_use_expand_flags()
@@ -222,6 +178,101 @@ def get_use(
     return (enabled_use, disabled_use)
 
 
+def get_use_expand_flags() -> Set[str]:
+    """Returns all currently enabled USE_EXPAND flags"""
+    flags = set()
+    for use in get_config().get("USE_EXPAND", []):
+        if not use.startswith("-"):
+            for flag in get_config().get(use, "").split():
+                flags.add(f"{use.lower()}_{flag}")
+    return flags
+
+
+def get_use_expand(pkg: Pybuild, use_expand: str) -> Tuple[Set[str], Set[str]]:
+    """
+    Returns the set of enabled flags for the given package and USE_EXPAND category
+    """
+    flags = {
+        re.sub(f"^{use_expand.lower()}_", "", flag)
+        for flag in pkg.IUSE_EFFECTIVE
+        if flag.startswith(f"{use_expand.lower()}_")
+    }
+    enabled_use = pkg.get_use()
+    enabled_expand = {
+        re.sub(f"^{use_expand}_", "", val, flags=re.IGNORECASE)
+        for val in enabled_use
+        if val.startswith(use_expand.lower() + "_")
+    }
+
+    return enabled_expand, flags - enabled_expand
+
+
+@prefix_aware_cache
+def get_user_global_use() -> Set[str]:
+    """Returns user-specified global use flags"""
+    global_use = cast(
+        Set[str], read_config(env.prefix().CONFIG, {}, user=True).get("USE", set())
+    )
+
+    # Also return global user-set USE_EXPAND values
+    for use in get_config().get("USE_EXPAND", []):
+        values = set(
+            read_config(env.prefix().CONFIG, {}, user=True).get(use, "").split()
+        )
+        flags = {use.lower() + "_" + value for value in values}
+        global_use |= flags
+
+    return global_use
+
+
+def _user_package_use_path() -> str:
+    """Returns the path of the user's package.use"""
+    return os.path.join(env.prefix().CONFIG_DIR, "package.use")
+
+
+@prefix_aware_cache
+def get_user_use(atom: Atom) -> Set[str]:
+    """Returns user-specified use flags for a given mod"""
+    use_file = _user_package_use_path()
+    if os.path.exists(use_file):
+        return get_flags(use_file, atom)
+
+    return set()
+
+
+def _iter_files(
+    directory: str, basename: Optional[str], suffix: str
+) -> Generator[str, None, None]:
+    if basename:
+        paths = [
+            ".".join([basename, suffix]),
+            ".".join([basename, sys.platform, suffix]),
+        ]
+    else:
+        paths = [".".join([suffix]), ".".join([sys.platform, suffix])]
+
+    for path in paths:
+        path = os.path.join(directory, path)
+        if os.path.exists(path):
+            yield path
+
+
+@prefix_aware_cache
+def get_forced_use(atom: Atom) -> Set[str]:
+    """Returns a list of forced use flags for the given mod"""
+    force: Set[str] = set()
+    for parent_dir in profile_parents():
+        for force_file in _iter_files(parent_dir, None, "use.force"):
+            flags = get_flags(force_file)
+            force = collapse_flags(force, flags)
+
+        for pkg_force_file in _iter_files(parent_dir, "package", "use.force"):
+            flags = get_flags(pkg_force_file, atom)
+            force = collapse_flags(force, flags)
+
+    return force
+
+
 def verify_use(flag: str, atom: Optional[Atom] = None) -> bool:
     """
     Verifies that the given flag is valid
@@ -248,75 +299,97 @@ def verify_use(flag: str, atom: Optional[Atom] = None) -> bool:
         ]
 
 
-def add_use(flag: str, atom: Optional[Atom] = None, disable: bool = False):
+def add_use(
+    flag: str,
+    atom: Atom,
+    disable: bool = False,
+    comment: Sequence[str] = (),
+    protect_file: Optional[str] = None,
+):
     """
     Adds the given use flag to the user's configuration
 
     Args:
         flag: Flag to be added
-        atom: If present, the flag will only apply to this package
+        atom: Package the flag applies to
         disable: If True, the flag is added in its disabled form (prefixed with "-")
+        comment: An optional comment to include with the flag override. Only meaningful
+                 with an ``atom`` argument.
+        protect: Whether or not the change should be protected by redirecting to a new
+                 file and registering with the cfg_protect system to be updated when
+                 cfg-update is run.
+                 Only meaningful with an ``atom`` argument.
     """
     from portmod.loader import load_pkg
 
-    if disable and flag in get_config().get("USE", []):
-        remove_use(flag, atom)
-
     disableflag = "-" + flag
 
-    if (disable and flag in get_config().get("USE", [])) or (
-        not disable and disableflag in get_config().get("USE", [])
-    ):
-        remove_use(flag, atom)
-
     if not verify_use(flag, atom):
-        if atom:
-            raise InvalidFlag(flag, atom)
-        else:
-            raise InvalidFlag(flag)
-        return
+        raise InvalidFlag(flag, atom)
 
-    if atom is not None:
-        from portmod.util import select_package
+    if not any(flag in pkg.IUSE_EFFECTIVE for pkg in load_pkg(atom)):
+        warning(l10n("invalid-use-flag-warning", flag=flag, atom=atom))
 
-        (newest, req) = select_package(load_pkg(atom))
-        if flag not in newest.IUSE_EFFECTIVE:
-            warning(
-                l10n(
-                    "invalid-use-flag-warning", flag=flag, atom1=newest.ATOM, atom2=atom
-                )
-            )
+    use_file = protect_file or _user_package_use_path()
 
-    if atom:
-        use_file = os.path.join(env.prefix().CONFIG_DIR, "package.use")
+    if comment:
+        with open(use_file, "a+", encoding="utf-8") as file:
+            for line in comment:
+                print(line, file=file)
+            if disable:
+                print(atom, disableflag, file=file)
+            else:
+                print(atom, flag, file=file)
+        info(l10n("flag-add", flag=flag, atom=atom, file=use_file))
+    else:
         if disable:
             remove_flag(use_file, atom, flag)
             add_flag(use_file, atom, disableflag)
         else:
             remove_flag(use_file, atom, disableflag)
             add_flag(use_file, atom, flag)
-        get_user_use.cache_clear()  # type: ignore
-    else:
-        GLOBAL_USE = get_config()["USE"]
+    get_user_use.cache_clear()
+    get_use.cache_clear()
 
-        if (not disable and flag not in GLOBAL_USE) or (
-            disable and disableflag not in GLOBAL_USE
-        ):
-            if disable:
-                info(l10n("adding-use-flag", flag="-" + flag))
-                GLOBAL_USE.add(disableflag)
-            else:
-                info(l10n("adding-use-flag", flag=flag))
-                GLOBAL_USE.add(flag)
 
-            set_config_value("USE", " ".join(sorted(GLOBAL_USE)))
-            get_user_global_use.cache_clear()  # type: ignore
+def add_global_use(flag: str, disable: bool = False):
+    """
+    Adds the given use flag to the user's global USE configuration
+
+    Args:
+        flag: Flag to be added
+        disable: If True, the flag is added in its disabled form (prefixed with "-")
+    """
+    disableflag = "-" + flag
+
+    if (disable and flag in get_config().get("USE", [])) or (
+        not disable and disableflag in get_config().get("USE", [])
+    ):
+        remove_use(flag)
+
+    if not verify_use(flag):
+        raise InvalidFlag(flag)
+
+    global_use = get_config()["USE"]
+
+    if (not disable and flag not in global_use) or (
+        disable and disableflag not in global_use
+    ):
+        if disable:
+            info(l10n("adding-use-flag", flag="-" + flag))
+            global_use.add(disableflag)
         else:
-            if disable:
-                warning(l10n("global-use-flag-already-disabled", flag=flag))
-            else:
-                warning(l10n("global-use-flag-already-enabled", flag=flag))
-    get_use.cache_clear()  # type: ignore
+            info(l10n("adding-use-flag", flag=flag))
+            global_use.add(flag)
+
+        set_config_value("USE", " ".join(sorted(global_use)))
+        get_user_global_use.cache_clear()
+    else:
+        if disable:
+            warning(l10n("global-use-flag-already-disabled", flag=flag))
+        else:
+            warning(l10n("global-use-flag-already-enabled", flag=flag))
+    get_use.cache_clear()
 
 
 def remove_use(flag: str, atom: Optional[Atom] = None):
@@ -337,10 +410,10 @@ def remove_use(flag: str, atom: Optional[Atom] = None):
         warning(l10n("invalid-flag-atom", flag=flag, atom=atom))
 
     if atom is not None:
-        use_file = os.path.join(env.prefix().CONFIG_DIR, "package.use")
+        use_file = _user_package_use_path()
         remove_flag(use_file, atom, flag)
         remove_flag(use_file, atom, disableflag)
-        get_user_use.cache_clear()  # type: ignore
+        get_user_use.cache_clear()
     else:
         GLOBAL_USE = get_config()["USE"]
 
@@ -354,7 +427,7 @@ def remove_use(flag: str, atom: Optional[Atom] = None):
                 GLOBAL_USE.remove(disableflag)
 
             set_config_value("USE", " ".join(sorted(GLOBAL_USE)))
-            get_user_global_use.cache_clear()  # type: ignore
+            get_user_global_use.cache_clear()
         else:
             warning(l10n("flag-not-set-globally", flag=flag))
-    get_use.cache_clear()  # type: ignore
+    get_use.cache_clear()
