@@ -18,6 +18,7 @@ from portmod.pybuild import Pybuild
 from portmod.source import LocalHashError, SourceManifest
 from portmodlib.fs import get_hash
 from portmodlib.l10n import l10n
+from portmodlib.portmod import directories
 from portmodlib.source import HashAlg, Source
 from portmodlib.usestr import use_reduce
 
@@ -86,10 +87,10 @@ def fetchable(
         return []
 
     if "mirror" not in restricted and mirrorable(mod, enabled_use):
-        return mod.get_sources(enabled_use)
+        return mod.get_source_manifests(enabled_use)
 
     can_fetch = []
-    for source in mod.get_sources(enabled_use):
+    for source in mod.get_source_manifests(enabled_use):
         parsedurl = urllib.parse.urlparse(source.url)
         if parsedurl.scheme:
             can_fetch.append(source)
@@ -281,7 +282,10 @@ def find_download(source: Source) -> Optional[str]:
 
     return (
         find_by_name(env.DOWNLOAD_DIR)
-        or find_by_name(os.path.expanduser(os.path.join("~", "Downloads")))
+        or find_by_name(
+            directories.download_dir
+            or os.path.expanduser(os.path.join("~", "Downloads"))
+        )
         or find_by_name(os.environ.get("DOWNLOADS", ""))
     )
 
@@ -290,7 +294,7 @@ def is_downloaded(mod: Pybuild, enabled_use: Set[str]) -> bool:
     """
     Returns true if all the mod's sources can be found
     """
-    for source in mod.get_sources(enabled_use):
+    for source in mod.get_source_manifests(enabled_use):
         cached = find_download(source)
         if cached is None:
             return False
@@ -388,9 +392,9 @@ def download_mod(
     """
     download_list = []
     if matchall:
-        sources = mod.get_sources(matchall=True)
+        sources = mod.get_source_manifests(matchall=True)
     else:
-        sources = mod.get_sources(enabled_flags)
+        sources = mod.get_source_manifests(enabled_flags)
 
     for source in sources:
         download_source(mod, source)
@@ -423,17 +427,9 @@ def get_download_size(packages: Dict[Pybuild, Set[str]]) -> float:
     """
     download_bytes = 0
     for mod, enabled_use in packages.items():
-        manifest_file = mod.get_manifest()
-        sources = mod.get_sources(enabled_use)
-        for manifest in manifest_file.entries.values():
-            source = next(
-                (source for source in sources if source.name == manifest.name), None
-            )
-            if (
-                manifest.file_type == FileType.DIST
-                and source is not None
-                and find_download(source) is None
-            ):
-                download_bytes += manifest.size
+        sources = mod.get_source_manifests(enabled_use)
+        for source in sources:
+            if find_download(source) is None:
+                download_bytes += source.size
 
     return download_bytes / 1024 / 1024
