@@ -20,7 +20,7 @@ _INSTALL_CACHE_FUNCS = []
 class _lru_cache_wrapper(Generic[_T]):
     __wrapped__: Callable[..., _T]
 
-    def __call__(self, *args: Hashable, **kwargs: Hashable) -> _T:
+    def __call__(self, *args: Hashable, **kwargs: Hashable) -> _T:  # type: ignore
         ...
 
     def cache_clear(self) -> None:
