@@ -12,7 +12,7 @@ import subprocess
 import sys
 import traceback
 from functools import wraps
-from logging import debug, warning
+from logging import debug, error, warning
 from typing import (
     Any,
     Callable,
@@ -45,6 +45,7 @@ from .globals import env
 from .perms import Permissions
 from .pybuild import File, InstallDir, InstalledPybuild, Pybuild
 from .repo.loader import (
+    __safe_load_module,
     _iterate_installed,
     _iterate_pybuilds,
     find_installed_path,
@@ -59,7 +60,7 @@ class AmbiguousAtom(Exception):
         message_id = "ambiguous-atom-fq" if fq else "ambiguous-atom"
         super().__init__(
             l10n(message_id, atom=green(atom))
-            + "\n"
+            + "\n  "
             + green("\n  ".join(sorted(packages)))
         )
 
@@ -67,12 +68,6 @@ class AmbiguousAtom(Exception):
 class SandboxedError(Exception):
     """Error raised when a sandboxed command fails"""
 
-    def __init__(self, message: str):
-        self.message = message
-
-    def __str__(self):
-        return f"An error was encountered when execuring code inside the sandbox: {self.message}"
-
 
 @system_cache
 def _state_path(file) -> str:
@@ -92,11 +87,14 @@ def get_wrapper_code():
         if sys.platform == "win32":
             file = os.path.join(
                 os.environ["VIRTUAL_ENV"], "scripts", "activate_this.py"
-            ).replace("\\", "\\\\")
+            )
+            # FIXME: Without this it's being parsed as escapes even with the raw string
+            # This shouldn't be necessary
+            file = file.replace("\\", "\\\\")
         else:
             file = os.path.join(os.environ["VIRTUAL_ENV"], "bin", "activate_this.py")
         venv_activate = (
-            'exec(open("' + file + '").read(), {"__file__": "' + file + '"})'
+            'exec(open(r"' + file + '").read(), {"__file__": "' + file + '"})'
         )
 
     return f"""
@@ -126,6 +124,8 @@ if __name__ == "__main__":
 def load_module(file: str, state):
     from portmod.modules import Module, ModuleFunction
 
+    module_data = __safe_load_module(file, False, None)
+
     perms = Permissions(
         rw_paths=[state.CACHE, state.ROOT],
         ro_paths=[
@@ -139,16 +139,12 @@ def load_module(file: str, state):
         tmp=state.TEMP,
     )
 
-    module_data = _sandbox_execute_module(file, "load", permissions=perms)
-
     def get_func_wrapper(function_name: str):
-
         if function_name == "update":
 
             def func_wrapper(state):
                 return _sandbox_execute_module(
                     file,
-                    "execute",
                     function=function_name,
                     init=state.__dict__,
                     permissions=perms,
@@ -159,7 +155,6 @@ def load_module(file: str, state):
             def func_wrapper(state, args):  # type: ignore
                 return _sandbox_execute_module(
                     file,
-                    "execute",
                     function=function_name,
                     args=args,
                     init=state.__dict__,
@@ -168,22 +163,43 @@ def load_module(file: str, state):
 
         return func_wrapper
 
+    do_functions = {}
+    descriptions = {}
+    describe_options = {}
+    describe_parameters = {}
+    for globname in module_data:
+        if globname.startswith("do_"):
+            name = re.sub("^do_", "", globname)
+            do_functions[name] = module_data[globname]
+
+        match = re.match("^describe_(.*)$", globname)
+        if match:
+            descriptions[match.group(1)] = str(module_data[globname]())
+        match = re.match("^describe_(.*)_options$", globname)
+        if match:
+            describe_options[match.group(1)] = module_data[globname]()
+        match = re.match("^describe_(.*)_parameters$", globname)
+        if match:
+            describe_parameters[match.group(1)] = module_data[globname]()
+
     functions = []
-    for function, data in module_data.get("functions", []).items():
+    for function_name in do_functions:
         functions.append(
             ModuleFunction(
-                function,
-                data.get("desc"),
-                get_func_wrapper(function),
-                data.get("options"),
-                data.get("parameters"),
+                function_name,
+                descriptions.get(function_name),
+                get_func_wrapper(function_name),
+                describe_options.get(function_name),
+                describe_parameters.get(function_name),
                 state,
             )
         )
+    module_name = os.path.basename(file)
+    module_name, _ = os.path.splitext(module_name)
 
     return Module(
-        module_data.get("name"),
-        module_data.get("desc"),
+        module_name,
+        module_data.get("__doc__"),
         sorted(functions, key=lambda x: x.name),
         state,
     )
@@ -206,11 +222,13 @@ def _get_library_dirs(path: str) -> Set[str]:
     else:
         try:
             if sys.platform == "darwin":
-                lines = execute(f"otool -L {path}", pipe_output=True)
+                lines = execute(f"otool -L {path}", pipe_output=True, pipe_error=True)
             else:
-                lines = execute(f"ldd {path}", pipe_output=True)
-        except subprocess.CalledProcessError:
-            return set()
+                lines = execute(f"ldd {path}", pipe_output=True, pipe_error=True)
+        except subprocess.CalledProcessError as err:
+            if "not a dynamic executable" in str(err.stderr):
+                return set()
+            error(err.stderr.decode("utf-8"))
 
         # Add anything that looks like an absolute path
         for token in (lines or "").split():
@@ -243,10 +261,6 @@ def _sandbox_execute(
 ):
     assert file_type in ("pybuild", "module")
     python = os.path.realpath(sys.executable)
-    print_actions = [
-        "load",
-        "dump-environment",
-    ]
 
     abspath = os.path.abspath(file)
     old_curdir = os.getcwd()
@@ -255,7 +269,7 @@ def _sandbox_execute(
     os.chdir(curdir or env.TMP_DIR)
     ro_paths = (
         set(permissions.ro_paths)
-        | {env.CONFIG_DIR, env.TMP_VDB, os.path.dirname(abspath)}
+        | {env.prefix().ROOT, env.CONFIG_DIR, env.TMP_VDB, os.path.dirname(abspath)}
         | {repo.location for repo in env.REPOS}
         # Python site packages directories, etc.
         | set(sys.path)
@@ -311,13 +325,7 @@ def _sandbox_execute(
                 ro_paths=sorted(ro_paths),
                 rw_paths=sorted(rw_paths),
             ),
-            pipe_output=action in print_actions,
         )
-    except subprocess.CalledProcessError as err:
-        debug(err)
-        raise SandboxedError(
-            l10n("command-failed", path=abspath, command=action)
-        ) from None
     finally:
         os.chdir(old_curdir)
     return result
@@ -325,7 +333,6 @@ def _sandbox_execute(
 
 def _sandbox_execute_module(
     file: str,
-    action: str,
     *,
     permissions: Permissions = Permissions(),
     args: Optional[Any] = None,
@@ -344,23 +351,24 @@ def _sandbox_execute_module(
     """
     # TODO: Allow modules to request network permissions
     os.makedirs(env.prefix().CONFIG_PROTECT_DIR, exist_ok=True)
-    result = _sandbox_execute(
-        "module",
-        file,
-        action,
-        Permissions(
-            permissions,
-            rw_paths=[env.prefix().CONFIG_PROTECT_DIR],
-        ),
-        init=init,
-        function=function,
-        args=args,
-    )
-
-    if action == "load":
-        if not result:
-            raise SandboxedError(f"Loading module {file} did not produce output!")
-        return json.loads(result)
+    try:
+        return _sandbox_execute(
+            "module",
+            file,
+            "execute",
+            Permissions(
+                permissions,
+                rw_paths=[env.prefix().CONFIG_PROTECT_DIR],
+            ),
+            init=init,
+            function=function,
+            args=args,
+        )
+    except subprocess.CalledProcessError as err:
+        debug(err)
+        raise SandboxedError(
+            l10n("sandboxed-error-module", path=file, function=function)
+        ) from None
 
 
 def _sandbox_execute_pybuild(
@@ -373,25 +381,27 @@ def _sandbox_execute_pybuild(
     curdir: Optional[str] = None,
     installed: bool = False,
 ):
-    permissions.rw_paths.append(env.PYBUILD_TMP_DIR)
     os.makedirs(env.WARNINGS_DIR, exist_ok=True)
     os.makedirs(env.MESSAGES_DIR, exist_ok=True)
-    result = _sandbox_execute(
-        "pybuild",
-        file,
-        action,
-        permissions,
-        save_state=save_state,
-        init=init,
-        curdir=curdir,
-        installed=installed,
-    )
+    try:
+        result = _sandbox_execute(
+            "pybuild",
+            file,
+            action,
+            permissions,
+            save_state=save_state,
+            init=init,
+            curdir=curdir,
+            installed=installed,
+        )
+    except subprocess.CalledProcessError as err:
+        debug(err)
+        raise SandboxedError(
+            l10n("sandboxed-error-pybuild", path=file, phase=action)
+        ) from None
     if action == "can-update-live":
         return result is True
 
-    if action in ["dump-environment"]:
-        return result
-
 
 V = TypeVar("V", bound=Any)
 
