@@ -12,6 +12,7 @@ from typing import Dict, Iterable, Optional
 from portmod.pybuild import Pybuild
 from portmodlib.atom import Atom, QualifiedAtom, atom_sat
 from portmodlib.colour import bright, green, lblue, lgreen, red, yellow
+from portmodlib.fs import onerror
 from portmodlib.l10n import l10n
 from portmodlib.module_util import _add_redirection
 
@@ -39,7 +40,12 @@ from .loader import (
     load_pkg,
     load_pkg_fq,
 )
-from .modules import clear_module_updates, require_module_updates, update_modules
+from .modules import (
+    clear_module_updates,
+    modules_need_updating,
+    require_module_updates,
+    update_modules,
+)
 from .package import install_pkg, remove_pkg
 from .parsers.flags import add_flag
 from .perms import Permissions
@@ -129,8 +135,8 @@ def _update_configuration(
     def create_protect_file(path: str):
         # get_protected_path will return the same path
         # if the original file does not exist
-        if not os.path.exists(license_file):
-            with open(license_file, "w", encoding="utf-8"):
+        if not os.path.exists(path):
+            with open(path, "w", encoding="utf-8"):
                 pass
         protect_file = get_protected_path(path)
         try:
@@ -138,6 +144,7 @@ def _update_configuration(
         except FileNotFoundError:
             pass
         _add_redirection(protect_file, path)
+        return protect_file
 
     if keyword_changes:
         for keyword in keyword_changes:
@@ -160,10 +167,10 @@ def _update_configuration(
             print("    {} {}".format(green(keyword.atom), c(keyword.keyword)))
 
         if not env.INTERACTIVE or prompt_bool(l10n("apply-changes-qn")):
-            protect_file = None
             keyword_file = _user_package_accept_keywords_path()
+            protect_file = None
             if protect:
-                create_protect_file(keyword_file)
+                protect_file = create_protect_file(keyword_file)
 
             for keyword in keyword_changes:
                 add_keyword(keyword.atom, keyword.keyword, protect_file=protect_file)
@@ -193,7 +200,7 @@ def _update_configuration(
             if not env.INTERACTIVE or prompt_bool(l10n("apply-changes-qn")):
                 license_file = _user_package_accept_license_path()
                 if protect and not protect_file:
-                    create_protect_file(license_file)
+                    protect_file = create_protect_file(license_file)
 
                 add_flag(protect_file or license_file, license.atom, license.license)
             else:
@@ -241,13 +248,7 @@ def _update_configuration(
         if not env.INTERACTIVE or prompt_bool(l10n("apply-changes-qn")):
             protect_file = None
             if protect:
-                use_file = _user_package_use_path()
-                protect_file = get_protected_path(use_file)
-                try:
-                    shutil.copy2(use_file, protect_file)
-                except FileNotFoundError:
-                    pass
-                _add_redirection(protect_file, use_file)
+                protect_file = create_protect_file(_user_package_use_path())
 
             for use in use_changes:
                 add_use(
@@ -409,7 +410,7 @@ def configure(
                 print(l10n("to-install"))
             print_transactions(transactions, verbose=verbose)
             print()
-    elif vfs_needs_sorting() and not transactions.pkgs:
+    elif (vfs_needs_sorting() or modules_need_updating()) and not transactions.pkgs:
         global_updates()
         info(l10n("nothing-else-to-do"))
         return
@@ -436,7 +437,7 @@ def configure(
     # Create a temporary VDB so that common packages needed for pkg_nofetch and pkg_pretend
     # but that haven't yet been installed can be found by the loader
     if os.path.exists(env.TMP_VDB):
-        shutil.rmtree(env.TMP_VDB)
+        shutil.rmtree(env.TMP_VDB, onerror=onerror)
     for trans in transactions.pkgs:
         if isinstance(trans, New) and trans.pkg.CATEGORY == "common":
             os.makedirs(os.path.join(env.TMP_VDB, "common", trans.pkg.PN))
@@ -450,7 +451,7 @@ def configure(
         for trans in transactions.pkgs:
             if not isinstance(trans, Delete):
                 can_fetch = fetchable(trans.pkg, trans.flags)
-                sources = trans.pkg.get_sources(trans.flags)
+                sources = trans.pkg.get_source_manifests(trans.flags)
                 to_fetch = [
                     source for source in sources if find_download(source) is None
                 ]
@@ -501,7 +502,7 @@ def configure(
             )
 
             total_size = 0
-            for source in trans.pkg.get_sources(trans.flags):
+            for source in trans.pkg.get_source_manifests(trans.flags):
                 total_size += source.size
 
             # We assume that files have a compression ratio of approximately 0.5
@@ -564,10 +565,11 @@ def configure(
             err = trans.pkg.ATOM
             break
 
-        require_vfs_sort()
         require_module_updates()
-        sort_vfs()
-        clear_vfs_sort()
+        if trans.pkg._PYBUILD_VER == 1:
+            require_vfs_sort()
+            sort_vfs()
+            clear_vfs_sort()
 
     for trans in merged.pkgs:
         messages = get_messages(trans.pkg)
@@ -595,15 +597,13 @@ def configure(
         # There was an error. We report the packages that were successfully merged and
         # note that an error occurred, however we still commit anyway.
         message = (
-            l10n("merge-success-and-error", num=len(transactions.pkgs), atom=err)
+            l10n("merge-success-and-error", num=len(merged.pkgs), atom=err)
             + "\n"
             + transstring.getvalue()
         )
     else:
         message = (
-            l10n("merge-success", num=len(transactions.pkgs))
-            + "\n"
-            + transstring.getvalue()
+            l10n("merge-success", num=len(merged.pkgs)) + "\n" + transstring.getvalue()
         )
 
     # Commit changes to installed database
@@ -615,9 +615,10 @@ def configure(
     # and thus can be removed, or deleted, and no longer need to be rebuilt
     for atom in get_set("rebuild"):
         installed_pkg = load_installed_pkg(atom)
-        if not installed_pkg or installed_pkg.CPN in [
-            trans.pkg.CPN for trans in merged.pkgs
-        ]:
+        if not installed_pkg or (
+            installed_pkg.CPN in [trans.pkg.CPN for trans in merged.pkgs]
+            and installed_pkg._PYBUILD_VER == 1
+        ):
             remove_set("rebuild", atom)
 
     for pkg in load_all_installed():
