@@ -221,7 +221,8 @@ def remove_pkg(pkg: InstalledPybuild, reinstall: bool = False):
             # Remove and stage changes
             vdb.git.rm(os.path.join(pkg.CATEGORY, pkg.PN), r=True, f=True)
             # Clean up unstaged files (e.g. pycache)
-            shutil.rmtree(db_path, ignore_errors=True, onerror=onerror)
+            if os.path.exists(db_path):
+                shutil.rmtree(db_path, onerror=onerror)
             clear_cache_for_path(os.path.join(db_path, os.path.basename(pkg.FILE)))
 
     # Remove from pybuild cache
@@ -316,7 +317,7 @@ def install_pkg(mod: Pybuild, use_flags: Set[str]):
     old_pkg = load_installed_pkg(Atom(mod.CPN))
 
     info(">>> Checking for conflicts...")
-    for (src, dst) in _iter_files_to_patch(
+    for src, dst in _iter_files_to_patch(
         state.D,
         final_install,
         case_sensitive=case_sensitive,
@@ -359,7 +360,7 @@ def install_pkg(mod: Pybuild, use_flags: Set[str]):
 
     overwrite_all = False
 
-    for (src, dst) in _iter_files_to_patch(
+    for src, dst in _iter_files_to_patch(
         state.D,
         final_install,
         case_sensitive=case_sensitive,
@@ -485,20 +486,21 @@ def install_pkg(mod: Pybuild, use_flags: Set[str]):
         _delete_state(mod.FILE)
         vdb.git.add(os.path.join(mod.CATEGORY, mod.PN, "environment.xz"))
 
-        path = os.path.join(db_path, "environment.xz")
-        if os.path.exists(path):
-            compressed_environment = lzma.LZMAFile(path)
-            try:
-                environment = json.load(compressed_environment)
-            except EOFError as e:
-                raise RuntimeError(f"Failed to read {path}") from e
+        if mod._PYBUILD_VER == 1:
+            path = os.path.join(db_path, "environment.xz")
+            if os.path.exists(path):
+                compressed_environment = lzma.LZMAFile(path)
+                try:
+                    environment = json.load(compressed_environment)
+                except EOFError as e:
+                    raise RuntimeError(f"Failed to read {path}") from e
 
-            if "REBUILD_FILES" in environment and environment["REBUILD_FILES"]:
-                manifest = Manifest()
-                for entry in get_rebuild_manifest(environment["REBUILD_FILES"]):
-                    manifest.add_entry(entry)
-                manifest.write(os.path.join(db_path, "REBUILD_FILES"))
-                vdb.git.add(os.path.join(db_path, "REBUILD_FILES"))
+                if "REBUILD_FILES" in environment and environment["REBUILD_FILES"]:
+                    manifest = Manifest()
+                    for entry in get_rebuild_manifest(environment["REBUILD_FILES"]):
+                        manifest.add_entry(entry)
+                    manifest.write(os.path.join(db_path, "REBUILD_FILES"))
+                    vdb.git.add(os.path.join(db_path, "REBUILD_FILES"))
 
         clear_cache_for_path(os.path.join(db_path, os.path.basename(mod.FILE)))
 
