@@ -13,10 +13,6 @@ from portmod.source import HashAlg
 from portmodlib.fs import get_hash
 
 
-class ManifestMissing(Exception):
-    """Inidcates a missing or invalid manifest entry"""
-
-
 def _grouper(n: int, iterable):
     "Collect data into fixed-length chunks or blocks"
     args = [iter(iterable)] * n
