@@ -35,7 +35,6 @@ from portmod.repo import get_repo_name, get_repo_root
 from portmod.source import SourceManifest
 from portmodlib._deprecated import File, InstallDir
 from portmodlib.atom import Atom, FQAtom, QualifiedAtom
-from portmodlib.colour import green
 from portmodlib.pybuild import (
     BasePybuild,
     FullInstalledPybuild,
@@ -59,9 +58,9 @@ class Pybuild(BasePybuild):
                 self.INSTALL_DIRS = [
                     InstallDir(**cast(Dict, idir)) for idir in self.INSTALL_DIRS  # type: ignore
                 ]
-            self.TAGS = set(self.TAGS)
         for keyword, value in kwargs.items():
             setattr(self, keyword, value)
+        self.version = atom.version
         self.ATOM = atom
         self.P = Atom(atom.P)
         self.PF = Atom(atom.PF)
@@ -94,7 +93,7 @@ class Pybuild(BasePybuild):
 
         return get_manifest(self.FILE)
 
-    def _get_sources(
+    def get_sources(
         self,
         uselist: AbstractSet[str] = frozenset(),
         masklist: AbstractSet[str] = frozenset(),
@@ -117,7 +116,7 @@ class Pybuild(BasePybuild):
         )
         return parse_arrow(sources)
 
-    def get_sources(
+    def get_source_manifests(
         self,
         uselist: AbstractSet[str] = frozenset(),
         masklist: AbstractSet[str] = frozenset(),
@@ -126,8 +125,9 @@ class Pybuild(BasePybuild):
     ) -> List[SourceManifest]:
         """
         Returns a list of sources that are enabled using the given configuration
+        including manifest information
         """
-        sources = self._get_sources(uselist, masklist, matchnone, matchall)
+        sources = self.get_sources(uselist, masklist, matchnone, matchall)
         manifest = self.get_manifest()
 
         manifested_sources: List[SourceManifest] = []
@@ -351,7 +351,7 @@ class Pybuild(BasePybuild):
 
         if self._PYBUILD_VER == 1:
             try:
-                all_sources = self._get_sources(matchall=True)
+                all_sources = self.get_sources(matchall=True)
             except Exception as e:
                 all_sources = []
                 errors.append(str(e))
@@ -369,7 +369,7 @@ class Pybuild(BasePybuild):
 
         manifest = self.get_manifest()
         try:
-            for source in self._get_sources(matchall=True):
+            for source in self.get_sources(matchall=True):
                 if manifest.get(source.name) is None:
                     errors.append(
                         f'Source "{source.name}" is not listed in the Manifest'
@@ -385,9 +385,7 @@ class Pybuild(BasePybuild):
 
         if len(errors) > 0:
             raise Exception(
-                "Pybuild {} contains the following errors:\n{}".format(
-                    green(self.FILE), "\n".join(errors)
-                )
+                f"Pybuild contains the following errors:{os.linesep + os.linesep.join(errors)}"
             )
 
 
@@ -486,7 +484,6 @@ def to_cache(pkg: FullPybuild) -> Dict:
         "S",
         "PATCHES",
         "_PYBUILD_VER",
-        "TAGS",
     ]:
         if hasattr(pkg, key):
             cache[key] = getattr(pkg, key)
