@@ -12,7 +12,6 @@ import re
 import shutil
 import sys
 from collections import defaultdict
-from functools import cmp_to_key
 from logging import info
 from multiprocessing import Process
 from time import sleep
@@ -24,13 +23,14 @@ from typing import (
     List,
     Optional,
     Sequence,
+    Set,
     Tuple,
     Union,
 )
 
 from progressbar import AnimatedMarker, ProgressBar, UnknownLength, Variable
 
-from portmodlib.atom import Atom, FQAtom, QualifiedAtom, atom_sat, version_gt
+from portmodlib.atom import Atom, FQAtom, QualifiedAtom, atom_sat
 from portmodlib.colour import blue, bright, cyan, green, lblue, lgreen, red, yellow
 from portmodlib.l10n import l10n
 from portmodlib.portmod import Group, PackageIndexData, Person
@@ -50,7 +50,6 @@ from .repo import get_repo
 from .repo.metadata import get_global_use
 from .repo.metadata import get_package_metadata as get_native_metadata
 from .repo.metadata import get_use_expand_values
-from .util import get_newest, sort_by_version
 
 Maintainer = Union[Group, Person]
 Maintainers = Union[Maintainer, List[Maintainer]]
@@ -81,7 +80,7 @@ def list_maintainers_to_human_strings(maintainers: List[str]) -> str:
 
 
 def print_depgraph(
-    mod: Pybuild, level: int, level_limit: int, seen: AbstractSet[Pybuild] = frozenset()
+    mod: Pybuild, level: int, level_limit: int, seen: Set[Pybuild]
 ) -> int:
     """
     Recursively prints the dependency graph for the given mod.
@@ -93,13 +92,19 @@ def print_depgraph(
         return level - 1
 
     deps = parse_usestr(mod.DEPEND + " " + mod.RDEPEND, token_class=Atom)
+
+    if mod in seen and deps:
+        print(" " * (level + 2) + "-- " + l10n("omit-already-displayed-tree"))
+        return level - 1
     max_level = level
 
-    new_seen = set(seen)
+    if isinstance(seen, frozenset):
+        seen = set()
+    seen.add(mod)
 
-    def print_token(token, conditional=None):
+    def print_token(token, conditionals=None):
         atom = Atom(token)
-        mod = get_newest(load_pkg(atom))
+        mod = max(load_pkg(atom), key=lambda pkg: pkg.version)
         enabled, _ = get_use(mod)
 
         def colour(flag):
@@ -112,32 +117,32 @@ def print_depgraph(
         if atom.USE:
             use_str = f'[{" ".join(use)}]'
 
-        if conditional:
-            dep = f"( {conditional} ( {atom.strip_use()} ) ) "
+        if conditionals:
+            dep = f"( {' '.join(conditionals)} ( {atom.strip_use()} ) ) "
         else:
             dep = f"({atom.strip_use()}) "
 
         print(" " * (level + 1) + f"-- {bright(green(mod.ATOM.CPF))} " + dep + use_str)
-        if mod in new_seen:
-            print(" " * level + "-- " + l10n("omit-already-displayed-tree"))
-            return level
+        return print_depgraph(mod, level + 1, level_limit, seen)
 
-        new_seen.add(mod)
-        return print_depgraph(mod, level + 1, level_limit, new_seen)
-
-    for token in deps:
-        if isinstance(token, list):
-            if token[0] == "||":
-                for inner_token in token[1:]:
-                    max_level = max(level, print_token(inner_token))
-            elif token[0].endswith("?"):
-                for inner_token in token[1:]:
-                    max_level = max(level, print_token(inner_token, token[0]))
+    def print_deps(deps, conditionals: List):
+        nonlocal max_level
+        if isinstance(deps, list):
+            if not deps:
+                return
+            if isinstance(deps[0], str) and deps[0] == "||":
+                for inner_token in deps[1:]:
+                    print_deps(inner_token, conditionals)
+            elif isinstance(deps[0], str) and deps[0].endswith("?"):
+                for inner_token in deps[1:]:
+                    print_deps(inner_token, conditionals + [deps[0]])
             else:
-                for inner_token in token:
-                    max_level = max(level, print_token(inner_token))
+                for inner_token in deps:
+                    print_deps(inner_token, conditionals)
         else:
-            max_level = max(level, print_token(token))
+            max_level = max(max_level, print_token(deps, conditionals))
+
+    print_deps(deps, [])
 
     return max_level
 
@@ -273,8 +278,8 @@ def display_search_results(
     for package in packages:
         count += 1
         group = load_pkg(Atom(package.cpn))
-        sortedmods = sort_by_version(group)
-        newest = get_newest(group)
+        sortedmods = sorted(group, key=lambda pkg: pkg.version)
+        newest = sortedmods[-1]
         installed = load_installed_pkg(Atom(package.cpn))
         download = get_total_download_size([newest])
 
@@ -546,13 +551,7 @@ def get_package_metadata(package: QualifiedAtom) -> Optional[PackageIndexData]:
     if not packages:
         return None
 
-    def version_cmp(x, y):
-        if version_gt(x.PVR, y.PVR):
-            return -1
-        else:
-            return 1
-
-    pkgs = sorted(packages, key=cmp_to_key(version_cmp))
+    pkgs = sorted(packages, key=lambda x: x.ATOM.version)
     newest = pkgs[-1]
 
     assert env.PREFIX_NAME, "A prefix must be specified"
@@ -577,9 +576,9 @@ def get_package_metadata(package: QualifiedAtom) -> Optional[PackageIndexData]:
         pkg_metadata.license = newest.LICENSE
 
     for pkg in pkgs:
-        pkg_metadata.tags |= pkg.TAGS
         metadata = get_native_metadata(pkg)
         if metadata:
+            pkg_metadata.tags |= metadata.tags
             if metadata.longdescription:
                 pkg_metadata.longdescription = metadata.longdescription
             if metadata.maintainer:
