@@ -18,6 +18,7 @@ from portmodlib.l10n import l10n
 
 
 def sync(repos: Iterable[Repo]):
+    old_prefix = env.set_prefix(None)
     # Slow imports
     import git
 
@@ -25,7 +26,6 @@ def sync(repos: Iterable[Repo]):
 
     for repo in to_sync:
         if repo.auto_sync and repo.sync_type == "git" and repo.sync_uri:
-
             if os.path.exists(repo.location):
                 info(l10n("syncing-repo", repo=repo.name))
                 gitrepo = git.Repo.init(repo.location)
@@ -111,4 +111,5 @@ def sync(repos: Iterable[Repo]):
                 shutil.rmtree(path)
 
     update_news()
+    env.set_prefix(old_prefix)
     update_index()
