@@ -16,7 +16,7 @@ from typing import (
     cast,
 )
 
-from portmodlib.atom import Atom, FQAtom, QualifiedAtom, atom_sat, version_gt
+from portmodlib.atom import Atom, FQAtom, QualifiedAtom, atom_sat
 from portmodlib.colour import blue, bright, green, lgreen, red, yellow
 from portmodlib.l10n import l10n
 from portmodlib.usestr import use_reduce
@@ -140,12 +140,6 @@ class Transactions:
         self.config |= trans.config
         self.new_selected |= trans.new_selected
 
-    def find(self, pkg: Pybuild) -> Optional[Trans]:
-        for trans in self.pkgs:
-            if pkg == trans.pkg:
-                return trans
-        return None
-
 
 class UseDep:
     def __init__(
@@ -245,9 +239,6 @@ def print_transactions(
     summarize: bool = True,
 ):
     pkgs = transactions.pkgs
-    download_size = get_download_size(
-        {trans.pkg: trans.flags for trans in pkgs if not isinstance(trans, Delete)}
-    )
 
     for trans in pkgs:
         pkg = trans.pkg
@@ -285,7 +276,7 @@ def print_transactions(
         fetchable_files = set(fetchable(trans.pkg, trans.flags))
         fetch_restricted = [
             source
-            for source in trans.pkg.get_sources(trans.flags)
+            for source in trans.pkg.get_source_manifests(trans.flags)
             if source not in fetchable_files
         ]
         if fetch_restricted:
@@ -301,6 +292,9 @@ def print_transactions(
         )
 
     if summarize:
+        download_size = get_download_size(
+            {trans.pkg: trans.flags for trans in pkgs if not isinstance(trans, Delete)}
+        )
         print(
             l10n(
                 "transaction-summary",
@@ -503,10 +497,10 @@ def generate_transactions(
                 return False
 
         if installed is not None:
-            if version_gt(installed.ATOM.PVR, (to_install or installed).ATOM.PVR):
+            if installed.version > (to_install or installed).version:
                 # to_install cannot be None if it has a smaller version
                 transactions.append(Downgrade(to_install, installed, flags))
-            elif version_gt((to_install or installed).ATOM.PVR, installed.ATOM.PVR) or (
+            elif ((to_install or installed).version > installed.version) or (
                 update
                 and "live"
                 in use_reduce(installed.PROPERTIES, installed.INSTALLED_USE, flat=True)
