@@ -18,18 +18,19 @@ def vdb_path() -> str:
 
 class VDB(ContextDecorator):
     def __init__(self, commit_message: Optional[str] = None):
-        # Slow import
-        import git
-
         self.lock = vdb_lock(write=True)
-        self.gitrepo = git.Repo.init(vdb_path())
         self.message = commit_message
 
     def __enter__(self):
+        # Slow import
+        import git
+
         self.lock.__enter__()
+        # Don't set the gitrepo until we have the write lock
+        self.gitrepo = git.Repo.init(vdb_path())
         return self.gitrepo
 
-    def __exit__(self, *exc):
+    def __exit__(self, *_exc):
         if self.message is not None and (
             not self.gitrepo.heads or self.gitrepo.git.diff("HEAD", cached=True)
         ):
