@@ -214,15 +214,22 @@ class Policy(RestrictingNodeTransformer):
         node = RestrictingNodeTransformer.visit_FunctionDef(self, node)
         if node.name == "__init__":
             newnode = ast.parse("super().__init__()").body[0]
+            # The interpreter needs correct line and column numbers
+            # for displaying traces.
+            # The inserted code doesn't actually exist in the source, but setting it
+            # to the previous line's position is close enough.
             newnode.lineno = node.lineno
             newnode.col_offset = node.col_offset
+            # the end numbers were added in python 3.8
+            # When 3.7 support is dropped, this if statement could be removed
+            if hasattr(node, "end_lineno"):
+                newnode.end_lineno = node.end_lineno
+                newnode.end_col_offset = node.end_col_offset
             node.body.insert(0, newnode)
         return node
 
 
 def restricted_load(code, filepath: str, _globals: Dict[str, Any]):
-    if sys.platform == "win32":
-        code = code.replace("\\", "\\\\")
     byte_code, errors, warnings, names = compile_restricted_exec(
         code, filename=filepath, policy=Policy
     )
