@@ -2,8 +2,8 @@
 # Distributed under the terms of the GNU General Public License v3
 
 import re
-from collections import namedtuple
-from typing import AbstractSet, Any, Dict, Optional, Set, TypeVar
+from dataclasses import dataclass
+from typing import AbstractSet, Any, Dict, List, Match, Optional, Set, TypeVar
 
 """
 Module for handling package atoms
@@ -23,8 +23,14 @@ _usedep_re = re.compile("^" + usedep_re + "$")
 
 op_re = r"(?P<B>(!!))?(?P<OP>([<>]=?|[<>=~]))?"
 cat_re = r"((?P<C>[A-Za-z0-9][A-Za-z0-9\-]*)/)?"
-ver_re = r"(\d+)((\.\d+)*)([a-z]?)((_(pre|p|beta|alpha|rc)\d*)*)"
-rev_re = r"(-(?P<PR>r[0-9]+))?"
+ver_re = (
+    r"(e(?P<EPOCH>\d+)-)?"
+    r"(?P<NUMERIC>(\d+)(\.\d+)*)"
+    r"(?P<LETTER>[a-z])?"
+    r"(?P<SUFFIX>((_(pre|p|beta|alpha|rc)\d*)*))"
+    r"(-r(?P<REV>\d+))?"
+)
+_ver_re = re.compile("^" + ver_re + "$")
 repo_re = r"(::(?P<R>[A-Za-z0-9_][A-Za-z0-9_-]*(::installed)?))?"
 _atom_re = re.compile(
     op_re
@@ -32,7 +38,6 @@ _atom_re = re.compile(
     + r"(?P<P>(?P<PN>[A-Za-z0-9+_-]+?)(-(?P<PV>"
     + ver_re
     + r"))?)"
-    + rev_re
     + repo_re
     + r"(\[(?P<USE>.*)\])?$"
 )
@@ -59,12 +64,19 @@ T = TypeVar("T", bound="Atom")
 
 
 class Atom(str):
-    CP: Optional[str]
-    """
-    The category, package name and version, excluding revision
+    @property
+    def CP(self) -> Optional[str]:
+        """
+        The category, package name and version, excluding revision
+
+        E.g. ``base/example-suite-1.0``
+        """
+        if self.CPN is None:
+            return None
+        if self.version is not None:
+            return self.CPN + "-" + self.version.display(revision=True)
+        return self.CPN
 
-    E.g. ``base/example-suite-1.0``
-    """
     CPN: Optional[str]
     """
     The category and package name
@@ -77,36 +89,60 @@ class Atom(str):
 
     E.g. ``{minimal}`` in ``base/example-suite[minimal]``
     """
-    P: str
-    """
-    The package name and version, excluding revision
 
-    E.g. ``example-suite-1.0``
-    """
+    @property
+    def P(self) -> str:
+        """
+        The package name and version, excluding revision
+
+        E.g. ``example-suite-1.0``
+        """
+        return (
+            self.PN
+            + "-"
+            + (self.version.display(revision=False) if self.version is not None else "")
+        )
+
     PN: str
     """
     The package name
 
     E.g. ``example-suite``
     """
-    PF: str
-    """
-    The package name and version, including revision
 
-    E.g. ``example-suite-1.0-r1``
-    """
-    PV: Optional[str]
-    """
-    The package version, not including revision
+    @property
+    def PF(self) -> str:
+        """
+        The package name and version, including revision
 
-    E.g. ``1.0``
-    """
-    PR: Optional[str]
-    """
-    The package revision
+        E.g. ``example-suite-1.0-r1``
+        """
+        return self.PN + (
+            "-" + self.version.display() if self.version is not None else ""
+        )
+
+    @property
+    def PV(self) -> Optional[str]:
+        """
+        The package version, not including revision
+
+        E.g. ``1.0``
+        """
+        if self.version is not None:
+            return self.version.display(revision=False)
+        return None
+
+    @property
+    def PR(self) -> Optional[str]:
+        """
+        The package revision
+
+        E.g. ``r1``
+        """
+        if self.version is not None:
+            return f"r{self.version.revision}"
+        return None
 
-    E.g. ``r1``
-    """
     C: Optional[str]
     """
     The package category
@@ -135,17 +171,36 @@ class Atom(str):
 
     E.g. ``!!base/example-suite``
     """
-    PVR: Optional[str]
-    """
-    The version and revision
 
-    E.g. 1.0-r1
-    """
-    CPF: str
-    """
-    The category, package name and version, including revision
+    @property
+    def PVR(self) -> Optional[str]:
+        """
+        The version and revision
 
-    E.g. ``base/example-suite-1.0-r1``
+        E.g. 1.0-r1
+        """
+        if self.version is not None:
+            return self.version.display(revision=True)
+        return None
+
+    @property
+    def CPF(self) -> str:
+        """
+        The category, package name and version, including revision
+
+        E.g. ``base/example-suite-1.0-r1``
+        """
+        if self.CPN is None:
+            prefix = self.PN
+        else:
+            prefix = self.CPN
+        if self.version is not None:
+            return prefix + "-" + self.version.display(revision=True)
+        return prefix
+
+    version: Optional["Version"] = None
+    """
+    The package's version
     """
 
     _CACHE: Dict[str, Any] = {}
@@ -159,11 +214,9 @@ class Atom(str):
         if not match:
             raise InvalidAtom("Invalid atom %s. Cannot parse" % (atom))
 
-        if match.group("P") and match.group("C"):
-            self.CP = match.group("C") + "/" + match.group("P")
+        if match.group("PN") and match.group("C"):
             self.CPN = match.group("C") + "/" + match.group("PN")
         else:
-            self.CP = None
             self.CPN = None
 
         if match.group("USE"):
@@ -175,29 +228,16 @@ class Atom(str):
                         "Invalid use dependency {} in atom {}".format(atom, x)
                     )
 
-        if match.group("PR"):
-            self.PF = match.group("P") + "-" + match.group("PR")
-        else:
-            self.PF = match.group("P")
+        if match.group("PV"):
+            self.version = Version("", _match=match)
 
-        self.P = match.group("P")
         self.PN = match.group("PN")
-        self.PV = match.group("PV")
-        self.PR = match.group("PR")
         self.C = match.group("C")
         self.R = match.group("R")
         self.OP = match.group("OP")
         self.BLOCK = match.group("B") is not None
-        self.PVR = self.PV
-        if self.PR:
-            self.PVR += "-" + self.PR
 
-        if self.C:
-            self.CPF = self.C + "/" + self.PF
-        else:
-            self.CPF = self.PF
-
-        if self.OP is not None and self.PV is None:
+        if self.OP is not None and self.version is None:
             raise InvalidAtom(
                 "Atom %s has a comparison operator but no version!" % (atom)
             )
@@ -286,10 +326,11 @@ class VAtom(QualifiedAtom):
 
     PV: str
     PVR: str
+    version: "Version"
 
     def __init__(self, atom: str):
         super().__init__(atom)
-        assert self.PV
+        assert self.version
 
 
 class FQAtom(VAtom):
@@ -302,9 +343,153 @@ class FQAtom(VAtom):
         assert self.R
 
 
-VersionMatch = namedtuple(
-    "VersionMatch", ["version", "numeric", "letter", "suffix", "revision"]
-)
+@dataclass
+class Version:
+    """
+    A package version
+
+    This class should be treated as immutable
+    """
+
+    numeric: List[str]
+    suffixes: List[str]
+    epoch: Optional[int] = None
+    letter: str = ""
+    revision: Optional[int] = None
+
+    def __init__(self, version: str, *, _match: Optional[Match[str]] = None):
+        """
+        args:
+            version: A string representation of the version to be parsed
+        """
+        if not _match:
+            match = _ver_re.match(version)
+            if match is None:
+                raise TypeError(f"Version {version} could not be parsed")
+        else:
+            match = _match
+
+        if match.group("EPOCH"):
+            self.epoch = int(match.group("EPOCH"))
+        self.numeric = list(str(match.group("NUMERIC")).split("."))
+        self.letter = match.group("LETTER") or ""
+        suffixes = match.group("SUFFIX")
+        if suffixes:
+            self.suffixes = suffixes.lstrip("_").split("_")
+        else:
+            self.suffixes = []
+        if match.group("REV"):
+            self.revision = int(match.group("REV"))
+
+    def __str__(self) -> str:
+        return self.display()
+
+    def display(self, *, revision: bool = True, epoch: bool = True) -> str:
+        return (
+            (f"e{self.epoch}-" if self.epoch is not None and epoch else "")
+            + ".".join(self.numeric)
+            + (self.letter or "")
+            + ("_" + "_".join(self.suffixes) if self.suffixes else "")
+            + (f"-r{self.revision}" if self.revision is not None and revision else "")
+        )
+
+    def _normalize_numeric(self) -> List[str]:
+        return list(map(lambda x: x.rstrip("0"), self.numeric))
+
+    def __eq__(self, other: object) -> bool:
+        if isinstance(other, Version):
+            return self.compare(other)
+        return False
+
+    def compare(self, other: "Version", *, ignore_revision=False) -> bool:
+        # Note: versions with different numbers of numeric components are not equivalent
+        # according to the PMS, even if the extra components are trailing 0s.
+        return (
+            self.epoch == other.epoch
+            and self._normalize_numeric() == other._normalize_numeric()
+            and self.letter == other.letter
+            and self.suffixes == other.suffixes
+            and (self.revision == other.revision or ignore_revision)
+        )
+
+    def __gt__(self, other: "Version") -> bool:
+        # Compare epochs
+        if (self.epoch or 0) > (other.epoch or 0):
+            return True
+        if (self.epoch or 0) < (other.epoch or 0):
+            return False
+
+        if int(self.numeric[0]) > int(other.numeric[0]):
+            return True
+        if int(self.numeric[0]) < int(other.numeric[0]):
+            return False
+
+        # Compare numeric components
+        for index, val in enumerate(self.numeric[1:], start=1):
+            if index >= len(other.numeric):
+                return True
+            if val.startswith("0") or other.numeric[index].startswith("0"):
+                # If either starts with a leading 0, strip trailing zeroes and
+                # compare lexicographically.
+                # I.e. 01 should always come before 10
+                my_stripped = val.rstrip("0")
+                other_stripped = other.numeric[index].rstrip("0")
+                if my_stripped > other_stripped:
+                    return True
+                if my_stripped < other_stripped:
+                    return False
+            else:
+                if int(val) > int(other.numeric[index]):
+                    return True
+                if int(val) < int(other.numeric[index]):
+                    return False
+        if len(other.numeric) > len(self.numeric):
+            return False
+
+        # Compare letter components
+        if self.letter > other.letter:
+            return True
+        if self.letter < other.letter:
+            return False
+
+        # Compare suffixes
+        for a_s, b_s in zip(self.suffixes, other.suffixes):
+            asm = re.match(r"(?P<S>[a-z]+)(?P<N>\d+)?", a_s)
+            bsm = re.match(r"(?P<S>[a-z]+)(?P<N>\d+)?", b_s)
+            assert asm
+            assert bsm
+            a_suffix = asm.group("S")
+            b_suffix = bsm.group("S")
+            a_suffix_num = int(asm.group("N") or "0")
+            b_suffix_num = int(bsm.group("N") or "0")
+            if a_suffix == b_suffix:
+                if b_suffix_num > a_suffix_num:
+                    return False
+                if a_suffix_num > b_suffix_num:
+                    return True
+            elif suffix_gt(a_suffix, b_suffix):
+                return True
+            else:
+                return False
+        # More suffixes implies an earlier version,
+        # except when the suffix is _p
+        if len(self.suffixes) > len(other.suffixes):
+            if self.suffixes[len(other.suffixes)].startswith("p"):
+                return True
+            return False
+        if len(self.suffixes) < len(other.suffixes):
+            if other.suffixes[len(self.suffixes)].startswith("p"):
+                return False
+            return True
+
+        # Compare revisions
+        if (self.revision or 0) > (other.revision or 0):
+            return True
+        if (self.revision or 0) < (other.revision or 0):
+            return False
+
+        # Equal
+        return False
 
 
 def suffix_gt(a_suffix: str, b_suffix: str) -> bool:
@@ -324,95 +509,7 @@ def version_gt(version1: str, version2: str) -> bool:
     returns:
         True if and only if version1 is greater than version2
     """
-    vre = re.compile(
-        r"(?P<NUMERIC>[\d\.]+)"
-        r"(?P<LETTER>[a-z])?"
-        r"(?P<SUFFIX>(_[a-z]+\d*)*)"
-        r"(-r(?P<REV>\d+))?"
-    )
-    match1 = vre.match(version1)
-    match2 = vre.match(version2)
-
-    assert match1 is not None
-    assert match2 is not None
-    v_match1 = VersionMatch(
-        version=version1,
-        numeric=match1.group("NUMERIC").split("."),
-        letter=match1.group("LETTER") or "",
-        suffix=match1.group("SUFFIX") or "",
-        revision=int(match1.group("REV") or "0"),
-    )
-    v_match2 = VersionMatch(
-        version=version2,
-        numeric=match2.group("NUMERIC").split("."),
-        letter=match2.group("LETTER") or "",
-        suffix=match2.group("SUFFIX") or "",
-        revision=int(match2.group("REV") or "0"),
-    )
-
-    # Compare numeric components
-    for index, val in enumerate(v_match1.numeric):
-        if index >= len(v_match2.numeric):
-            return True
-        if int(val) > int(v_match2.numeric[index]):
-            return True
-        if int(val) < int(v_match2.numeric[index]):
-            return False
-    if len(v_match2.numeric) > len(v_match1.numeric):
-        return False
-
-    # Compare letter components
-    if v_match1.letter > v_match2.letter:
-        return True
-    if v_match1.letter < v_match2.letter:
-        return False
-
-    # Compare suffixes
-    if v_match1.suffix:
-        a_suffixes = v_match1.suffix.lstrip("_").split("_")
-    else:
-        a_suffixes = []
-    if v_match2.suffix:
-        b_suffixes = v_match2.suffix.lstrip("_").split("_")
-    else:
-        b_suffixes = []
-    for a_s, b_s in zip(a_suffixes, b_suffixes):
-        asm = re.match(r"(?P<S>[a-z]+)(?P<N>\d+)?", a_s)
-        bsm = re.match(r"(?P<S>[a-z]+)(?P<N>\d+)?", b_s)
-        assert asm
-        assert bsm
-        a_suffix = asm.group("S")
-        b_suffix = bsm.group("S")
-        a_suffix_num = int(asm.group("N") or "0")
-        b_suffix_num = int(bsm.group("N") or "0")
-        if a_suffix == b_suffix:
-            if b_suffix_num > a_suffix_num:
-                return False
-            if a_suffix_num > b_suffix_num:
-                return True
-        elif suffix_gt(a_suffix, b_suffix):
-            return True
-        else:
-            return False
-    # More suffixes implies an earlier version,
-    # except when the suffix is _p
-    if len(a_suffixes) > len(b_suffixes):
-        if a_suffixes[len(b_suffixes)].startswith("p"):
-            return True
-        return False
-    if len(a_suffixes) < len(b_suffixes):
-        if b_suffixes[len(a_suffixes)].startswith("p"):
-            return False
-        return True
-
-    # Compare revisions
-    if v_match1.revision > v_match2.revision:
-        return True
-    if v_match1.revision < v_match2.revision:
-        return False
-
-    # Equal
-    return False
+    return Version(version1) > Version(version2)
 
 
 def atom_sat(specific: Atom, generic: Atom, *, ignore_name: bool = False) -> bool:
@@ -438,18 +535,27 @@ def atom_sat(specific: Atom, generic: Atom, *, ignore_name: bool = False) -> boo
         # Simple atom, either one version or all versions will satisfy
 
         # Check if version is correct
-        if generic.PV and (specific.PV != generic.PV):
+        if generic.version and (
+            not specific.version
+            or not specific.version.compare(generic.version, ignore_revision=True)
+        ):
             return False
 
         # Check if revision is correct
-        if generic.PR and (specific.PR != generic.PR):
+        if (
+            generic.version
+            and generic.version.revision
+            and (
+                not specific.version
+                or specific.version.revision != generic.version.revision
+            )
+        ):
             return False
-    elif generic.PV and specific.PV:
-        assert generic.PVR and specific.PVR
-        equal = specific.PVR == generic.PVR
-        verequal = specific.PV == generic.PV
-        lessthan = version_gt(generic.PVR, specific.PVR)
-        greaterthan = version_gt(specific.PVR, generic.PVR)
+    elif generic.version and specific.version:
+        equal = specific.version == generic.version
+        verequal = specific.version.compare(generic.version, ignore_revision=True)
+        lessthan = specific.version < generic.version
+        greaterthan = specific.version > generic.version
 
         if generic.OP == "=":
             return equal
