@@ -28,27 +28,3 @@ def prefix_aware_cache(func: F) -> F:
 
     prefix_wrapper.cache_clear = inner.cache_clear  # type: ignore
     return cast(F, prefix_wrapper)
-
-
-_VFS_CACHE_FUNCS = []
-
-
-def vfs_cache(func: F) -> F:
-    """
-    A variant of functools.lru_cache which treats the prefix as if it were an argument
-    """
-    global _VFS_CACHE_FUNCS
-
-    @wraps(func)
-    @prefix_aware_cache
-    def inner(*args, **kwargs):
-        return func(*args, **kwargs)
-
-    _VFS_CACHE_FUNCS.append(inner)
-
-    return cast(F, inner)
-
-
-def clear_vfs_cache():
-    for func in _VFS_CACHE_FUNCS:
-        func.cache_clear()  # type: ignore
