@@ -6,7 +6,7 @@ from typing import Optional
 
 
 def vdb_path() -> str:
-    return os.environ["PORTMOD_INSTALLED_DB"]
+    return os.path.join(root(), os.environ["VARIABLE_DATA"], "db")
 
 
 def prefix_name() -> Optional[str]:
