@@ -19,7 +19,10 @@ def _default_locale():
     """Returns the default locale"""
     try:
         locale.setlocale(locale.LC_ALL, "")
-        return str(locale.getdefaultlocale()[0])
+        lang, _ = locale.getdefaultlocale()
+        if lang is None:
+            return "en_GB"
+        return str(lang)
     except locale.Error:
         # If default fails, fall back to the C locale, which should hopefully work
         locale.setlocale(locale.LC_ALL, "C")
@@ -28,10 +31,15 @@ def _default_locale():
 
 def l10n(msg_id: str, **kwargs) -> str:
     """
-    Wrapper around FluentLocalization.format_value
+    Fetches a localised message and formats it with the given arguments
 
-    Unlike format_value, arguments are passed as keyword arguemnts
-    rather than as a dictionary.
+    Wrapper around portmodlib.portmod.l10n_lookup, in the Rust extension,
+    which itself is built on top of
+    `fluent_templates <https://github.com/XAMPPRocky/fluent-templates>`__
+
+    args:
+        msg_id: The message identifier
+        kwargs: Arguments passed to the fluent formatter
     """
     # Get locale before formatting numbers so that LC_ALL gets set properly
     default = _default_locale()
