@@ -55,12 +55,3 @@ def add_logging_arguments(parser):
     parser.add_argument(
         "-v", "--verbose", help=l10n("verbose-help"), action="store_true"
     )
-
-
-__MESSAGES = set()
-
-
-def warn_once(message: str):
-    if message not in __MESSAGES:
-        logging.warning(message)
-        __MESSAGES.add(message)
