@@ -12,6 +12,10 @@ def get_masters(file: str) -> Set[str]:
     """
     Detects masters for the given file
 
+    .. warning::
+        This function has been deprecated as of Portmod 2.4
+        it will be removed in Portmod 3.0
+
     args:
         file: File to be examined
     returns:
