@@ -10,9 +10,9 @@ import json
 import lzma
 import os
 from pathlib import Path
-from typing import Any, List, Optional, Set
+from typing import Any, List, Optional, Set, Union
 
-from .atom import Atom, FQAtom, QualifiedAtom
+from .atom import Atom, FQAtom, QualifiedAtom, Version
 from .source import Source
 from .usestr import use_reduce
 
@@ -27,6 +27,7 @@ class BasePybuild:
     __file__ = __file__
     _PYBUILD_VER: int
 
+    version: Version
     ATOM: FQAtom
     RDEPEND: str = ""
     DEPEND: str = ""
@@ -57,7 +58,6 @@ class BasePybuild:
     INSTALLED: bool = False
     S: Optional[str] = None  # Primary directory during prepare and install operations:w
     PATCHES: str = ""
-    TAGS: Set[str] = set()
     # Phase functions defined by the pybuild (or superclasses other than Pybuild1/2)
     # Used to determine if a function should be run, as certain functions don't have any default
     # behaviour
@@ -92,7 +92,7 @@ class FullPybuild(BasePybuild):
     WORKDIR: str  # Path of the working directory
 
     # Note: declared as a string, but converted into a set during __init__
-    IUSE = ""  # type: ignore
+    IUSE: Union[Set[str], str] = ""  # type: ignore
     KEYWORDS = ""
 
     def __init__(self):
@@ -103,6 +103,7 @@ class FullPybuild(BasePybuild):
         self.ATOM = Atom(  # type: ignore
             "{}/{}".format(category, os.path.basename(self.FILE)[: -len(".pybuild")])
         )
+        self.version = self.ATOM.version
 
         self.REPO_PATH = str(Path(self.FILE).resolve().parent.parent.parent)
         repo_name_path = os.path.join(self.REPO_PATH, "profiles", "repo_name")
@@ -124,8 +125,8 @@ class FullPybuild(BasePybuild):
 
         self.IUSE_EFFECTIVE = set()
 
-        if type(self.IUSE) is str:
-            self.IUSE = set(self.IUSE.split())  # type: ignore # pylint: disable=no-member
+        if isinstance(self.IUSE, str):
+            self.IUSE = set(self.IUSE.split())
             self.IUSE_EFFECTIVE |= set([use.lstrip("+") for use in self.IUSE])
         else:
             raise TypeError("IUSE must be a space-separated list of use flags")
