@@ -8,6 +8,10 @@ from portmodlib.atom import Atom, InvalidAtom, useflag_re
 from portmodlib.l10n import l10n
 
 
+class UseParserError(Exception):
+    """Error indicating a failure to parse a use-conditional string"""
+
+
 def use_reduce(
     depstr: str,
     uselist: AbstractSet[str] = set(),
@@ -72,10 +76,10 @@ def use_reduce(
                     "USE flag '{}' referenced in conditional '{}' "
                     "is not in IUSE".format(flag, conditional)
                 )
-                raise Exception(msg)
+                raise UseParserError(msg)
         else:
             if useflag_re.match(flag) is None:
-                raise Exception(
+                raise UseParserError(
                     "invalid use flag '{}' in conditional '{}'".format(
                         flag, conditional
                     )
@@ -103,7 +107,7 @@ def use_reduce(
         """
         for x in (")", "(", "||"):
             if token.startswith(x) or token.endswith(x):
-                raise Exception(
+                raise UseParserError(
                     "missing whitespace around '%s' at '%s', token %s"
                     % (x, token, pos + 1)
                 )
@@ -125,11 +129,11 @@ def use_reduce(
     for pos, token in enumerate(mysplit):
         if token == "(":
             if need_simple_token:
-                raise Exception(
+                raise UseParserError(
                     "expected: file name, got: '%s', token %s" % (token, pos + 1)
                 )
             if len(mysplit) >= pos + 2 and mysplit[pos + 1] == ")":
-                raise Exception(
+                raise UseParserError(
                     "expected: dependency string, got: ')', token %s" % (pos + 1,)
                 )
             need_bracket = False
@@ -137,9 +141,11 @@ def use_reduce(
             level += 1
         elif token == ")":
             if need_bracket:
-                raise Exception("expected: '(', got: '%s', token %s" % (token, pos + 1))
+                raise UseParserError(
+                    "expected: '(', got: '%s', token %s" % (token, pos + 1)
+                )
             if need_simple_token:
-                raise Exception(
+                raise UseParserError(
                     "expected: file name, got: '%s', token %s" % (token, pos + 1)
                 )
             if level > 0:
@@ -266,38 +272,42 @@ def use_reduce(
                             special_append()
 
             else:
-                raise Exception(
+                raise UseParserError(
                     "no matching '%s' for '%s', token %s" % ("(", ")", pos + 1)
                 )
         elif token == "||":
             if is_src_uri:
-                raise Exception(
+                raise UseParserError(
                     "any-of dependencies are not allowed in SRC_URI: token %s"
                     % (pos + 1,)
                 )
             if need_bracket:
-                raise Exception("expected: '(', got: '%s', token %s" % (token, pos + 1))
+                raise UseParserError(
+                    "expected: '(', got: '%s', token %s" % (token, pos + 1)
+                )
             need_bracket = True
             stack[level].append(token)
         elif token == "->":
             if need_simple_token:
-                raise Exception(
+                raise UseParserError(
                     "expected: file name, got: '%s', token %s" % (token, pos + 1)
                 )
             if not is_src_uri:
-                raise Exception(
+                raise UseParserError(
                     "SRC_URI arrow are only allowed in SRC_URI: token %s" % (pos + 1,)
                 )
             need_simple_token = True
             stack[level].append(token)
         else:
             if need_bracket:
-                raise Exception("expected: '(', got: '%s', token %s" % (token, pos + 1))
+                raise UseParserError(
+                    "expected: '(', got: '%s', token %s" % (token, pos + 1)
+                )
 
             if need_simple_token and "/" in token:
                 # The last token was a SRC_URI arrow,
                 # make sure we have a simple file name.
-                raise Exception(
+                raise UseParserError(
                     "expected: file name, got: '%s', token %s" % (token, pos + 1)
                 )
 
@@ -312,12 +322,14 @@ def use_reduce(
                         token = token_class(token)
                     except InvalidAtom as e:
                         missing_white_space_check(token, pos)
-                        raise Exception("Invalid atom (%s), token %s" % (e, pos + 1))
+                        raise UseParserError(
+                            "Invalid atom (%s), token %s" % (e, pos + 1)
+                        )
                     except SystemExit:
                         raise
-                    except Exception:
+                    except UseParserError:
                         missing_white_space_check(token, pos)
-                        raise Exception(
+                        raise UseParserError(
                             "Invalid token '%s', token %s" % (token, pos + 1)
                         )
 
@@ -327,13 +339,13 @@ def use_reduce(
             stack[level].append(token)
 
     if level != 0:
-        raise Exception("Missing '%s' at end of string" % (")",))
+        raise UseParserError("Missing '%s' at end of string" % (")",))
 
     if need_bracket:
-        raise Exception("Missing '%s' at end of string" % ("(",))
+        raise UseParserError("Missing '%s' at end of string" % ("(",))
 
     if need_simple_token:
-        raise Exception("Missing file name at end of string")
+        raise UseParserError("Missing file name at end of string")
 
     return stack[0]
 
@@ -366,7 +378,7 @@ def check_required_use(
             is_negated = False
 
         if not flag or not iuse_match(flag):
-            raise Exception("USE flag '%s' is not in IUSE" % (flag,))
+            raise UseParserError("USE flag '%s' is not in IUSE" % (flag,))
 
         return (flag in use and not is_negated) or (flag not in use and is_negated)
 
@@ -392,7 +404,7 @@ def check_required_use(
             level += 1
         elif token == ")":
             if need_bracket:
-                raise Exception("malformed syntax: '%s'" % required_use)
+                raise UseParserError("malformed syntax: '%s'" % required_use)
             if level > 0:
                 level -= 1
                 ll = stack.pop()
@@ -419,15 +431,15 @@ def check_required_use(
                     if ll:
                         stack[level].append(satisfied)
             else:
-                raise Exception("malformed syntax: '%s'" % required_use)
+                raise UseParserError("malformed syntax: '%s'" % required_use)
         elif token in valid_operators:
             if need_bracket:
-                raise Exception("malformed syntax: '%s'" % required_use)
+                raise UseParserError("malformed syntax: '%s'" % required_use)
             need_bracket = True
             stack[level].append(token)
         else:
             if need_bracket:
-                raise Exception("malformed syntax: '%s'" % required_use)
+                raise UseParserError("malformed syntax: '%s'" % required_use)
 
             if token[-1] == "?":
                 need_bracket = True
@@ -437,7 +449,7 @@ def check_required_use(
                 stack[level].append(satisfied)
 
     if level != 0 or need_bracket:
-        raise Exception("malformed syntax: '%s'" % required_use)
+        raise UseParserError("malformed syntax: '%s'" % required_use)
 
     return False not in stack[0]
 
@@ -463,21 +475,21 @@ def parse_usestr(usestr: str, token_class: Type = str):
             level += 1
         elif token == ")":
             if need_bracket:
-                raise Exception(f"malformed syntax: '{usestr}'")
+                raise UseParserError(f"malformed syntax: '{usestr}'")
             if level > 0:
                 level -= 1
                 ll = stack.pop()
                 stack[level].append(ll)
             else:
-                raise Exception(f"malformed syntax: '{usestr}'")
+                raise UseParserError(f"malformed syntax: '{usestr}'")
         elif token in valid_operators:
             if need_bracket:
-                raise Exception(f"malformed syntax: '{usestr}'")
+                raise UseParserError(f"malformed syntax: '{usestr}'")
             need_bracket = True
             stack[level].append(token)
         else:
             if need_bracket:
-                raise Exception(f"malformed syntax: '{usestr}'")
+                raise UseParserError(f"malformed syntax: '{usestr}'")
 
             if token[-1] == "?":
                 need_bracket = True
@@ -486,7 +498,7 @@ def parse_usestr(usestr: str, token_class: Type = str):
                 stack[level].append(token_class(token))
 
     if level != 0 or need_bracket:
-        raise Exception(f"malformed syntax: '{usestr}'")
+        raise UseParserError(f"malformed syntax: '{usestr}'")
 
     def opconvert(tokenlist):
         index = 0
