@@ -7,18 +7,28 @@ The module accessible within pybuilds
 Note that this module should not be imported outside of pybuild files
 """
 
+from portmodlib._deprecated import (  # noqa  # pylint: disable=unused-import
+    File,
+    InstallDir,
+)
+from portmodlib._deprecated.vfs import (  # noqa  # pylint: disable=unused-import
+    find_file,
+    list_dir,
+)
 from portmodlib.atom import version_gt  # noqa  # pylint: disable=unused-import
 from portmodlib.fs import patch_dir  # noqa  # pylint: disable=unused-import
 from portmodlib.globals import download_dir as _download_dir
 from portmodlib.masters import get_masters  # noqa  # pylint: disable=unused-import
-from portmodlib.pybuild import File, InstallDir  # noqa  # pylint: disable=unused-import
 from portmodlib.usestr import (  # noqa  # pylint: disable=unused-import
     check_required_use,
     use_reduce,
 )
-from portmodlib.vfs import find_file, list_dir  # noqa  # pylint: disable=unused-import
 
-from .pybuild import Pybuild1, apply_patch  # noqa  # pylint: disable=unused-import
+from ._pybuild import (  # noqa  # pylint: disable=unused-import
+    Pybuild1,
+    Pybuild2,
+    apply_patch,
+)
 
 DOWNLOAD_DIR = _download_dir()
 
@@ -32,6 +42,7 @@ __all__ = [
     "File",
     "InstallDir",
     "Pybuild1",
+    "Pybuild2",
     "apply_patch",
     "DOWNLOAD_DIR",
 ]
