@@ -454,13 +454,6 @@ class Pybuild2(FullPybuild):
     """
     A list of documentation patterns for the default ``src_install`` to install using :py:attr:`Pybuild2.dodoc`
     """
-    TAGS: Set[str] = set()
-    """
-    A list of tags which describe this package.
-
-    These tags are primarily used by the search indexer, and may be used by external
-    software to categorise packages.
-    """
     _PYBUILD_VER = 2
 
     def src_prepare(self):
@@ -917,7 +910,7 @@ class Pybuild1(Pybuild2):
             else:
                 to_install.append((source, install_dir, False))
 
-        for (source, install_dir, enabled) in to_install:
+        for source, install_dir, enabled in to_install:
             source_dir_path = os.path.join(
                 install_dir.S or cast(str, self.S), install_dir.PATH
             )
