@@ -2,7 +2,7 @@ use std::fs::File;
 use std::io::prelude::*;
 use std::io::{Error, ErrorKind};
 
-pub fn get_dds_dimensions(file: String) -> Result<(u32, u32), Error> {
+pub fn get_dds_dimensions(file: &str) -> Result<(u32, u32), Error> {
     let mut f = File::open(file)?;
     let mut buffer = [0; 24];
     f.read_exact(&mut buffer)?;
