@@ -15,6 +15,7 @@ use crate::metadata::{
 use crate::news::News;
 use crate::yaml::parse_yaml;
 use digest::Digest;
+use directories::{ProjectDirs, UserDirs};
 use esplugin::{GameId, Plugin};
 use fluent_bundle::types::FluentValue;
 use fluent_templates::Loader;
@@ -26,6 +27,8 @@ use unic_langid::LanguageIdentifier;
 
 use pyo3::prelude::*;
 use pyo3::types::{PyDict, PyFloat, PyLong};
+
+use pyo3::exceptions::PyFileNotFoundError;
 use pyo3::wrap_pyfunction;
 
 #[cfg(debug_assertions)]
@@ -94,64 +97,64 @@ fn main() {
     use pyo3::prelude::*;
 
     #[pyfunction]
-    pub fn parse_package_metadata(filename: String) -> PyResult<PackageMetadata> {
+    pub fn parse_package_metadata(filename: &str) -> PyResult<PackageMetadata> {
         Ok(parse_yaml(filename)?)
     }
 
     #[pyfunction]
-    pub fn parse_category_metadata(filename: String) -> PyResult<CategoryMetadata> {
+    pub fn parse_category_metadata(filename: &str) -> PyResult<CategoryMetadata> {
         Ok(parse_yaml(filename)?)
     }
 
     #[pyfunction]
-    pub fn parse_yaml_dict(filename: String) -> PyResult<HashMap<String, String>> {
+    pub fn parse_yaml_dict(filename: &str) -> PyResult<HashMap<String, String>> {
         Ok(parse_yaml(filename)?)
     }
 
     #[pyfunction]
-    pub fn parse_groups(filename: String) -> PyResult<HashMap<String, GroupDeclaration>> {
+    pub fn parse_groups(filename: &str) -> PyResult<HashMap<String, GroupDeclaration>> {
         Ok(parse_yaml(filename)?)
     }
 
     #[pyfunction]
     pub fn parse_yaml_dict_dict(
-        filename: String,
+        filename: &str,
     ) -> PyResult<HashMap<String, HashMap<String, String>>> {
         Ok(parse_yaml(filename)?)
     }
 
     #[pyfunction]
-    pub fn parse_news(filename: String) -> PyResult<News> {
+    pub fn parse_news(filename: &str) -> PyResult<News> {
         Ok(parse_yaml(filename)?)
     }
 
     #[pyfunction]
-    fn get_masters(filename: String) -> PyResult<Vec<String>> {
+    fn get_masters(filename: &str) -> PyResult<Vec<String>> {
         let mut plugin = Plugin::new(GameId::Morrowind, Path::new(&filename));
         plugin
             .parse_file(true)
-            .map_err(|x| crate::error::Error::Plugin(filename.clone(), x))?;
+            .map_err(|x| crate::error::Error::Plugin(filename.to_string(), x))?;
         let list = plugin
             .masters()
-            .map_err(|x| crate::error::Error::Plugin(filename.clone(), x))?;
+            .map_err(|x| crate::error::Error::Plugin(filename.to_string(), x))?;
         Ok(list)
     }
 
     #[pyfunction]
-    fn dds_dimensions(file: String) -> PyResult<(u32, u32)> {
+    fn dds_dimensions(file: &str) -> PyResult<(u32, u32)> {
         let (width, height) = get_dds_dimensions(file)?;
         Ok((width, height))
     }
 
     #[pyfunction]
-    fn l10n_lookup(lang: String, text_id: String, args: &PyDict) -> PyResult<String> {
+    fn l10n_lookup(lang: &str, text_id: &str, args: &PyDict) -> PyResult<String> {
         let lang_id: LanguageIdentifier = match lang.parse() {
             Ok(lang_id) => lang_id,
             Err(_) => {
                 let gil = Python::acquire_gil();
                 let py = gil.python();
-                let log = py.import("portmodlib.log")?;
-                log.getattr("warn_once")?.call(
+                let log = py.import("warnings")?;
+                log.getattr("warn")?.call(
                     (format!(
                         "User language identifier \"{}\" could not be parsed",
                         lang
@@ -186,19 +189,15 @@ fn main() {
         }
         let args: HashMap<String, FluentValue> = args.into_iter().map(|x| x.unwrap()).collect();
         #[cfg(debug_assertions)]
-        return ARC_LOADER.with(|loader| Ok(loader.lookup_with_args(&lang_id, &text_id, &args)));
+        return ARC_LOADER.with(|loader| Ok(loader.lookup_with_args(&lang_id, text_id, &args)));
         #[cfg(not(debug_assertions))]
-        Ok(STATIC_LOADER.lookup_with_args(&lang_id, &text_id, &args))
+        Ok(STATIC_LOADER.lookup_with_args(&lang_id, text_id, &args))
     }
 
     /// Hashes the given file
     /// 30MB appears to be a good buffer size for both large and small files
     #[pyfunction]
-    fn _get_hash(
-        filename: String,
-        funcs: Vec<String>,
-        buffer_size: usize,
-    ) -> PyResult<Vec<String>> {
+    fn _get_hash(filename: &str, funcs: Vec<&str>, buffer_size: usize) -> PyResult<Vec<String>> {
         let mut results: HashMap<&str, String> = HashMap::new();
 
         fn get_hash<T: Digest, R: std::io::Read>(
@@ -225,7 +224,7 @@ fn main() {
         for func in &funcs {
             let file = std::fs::File::open(&filename)?;
             let mut reader = BufReader::with_capacity(buffer_size, file);
-            match func.as_str() {
+            match *func {
                 "BLAKE3" => {
                     let mut hasher = blake3::Hasher::new();
                     loop {
@@ -255,13 +254,13 @@ fn main() {
                 "MD5" => {
                     results.insert("MD5", get_hash(md5::Md5::new(), &mut reader)?);
                 }
-                _ => return Err(error::Error::UnsupportedHashType(func.clone()).into()),
+                _ => return Err(error::Error::UnsupportedHashType(func.to_string()).into()),
             }
         }
 
         Ok(funcs
             .iter()
-            .map(|func| results[func.as_str()].clone())
+            .map(|func| results.remove(func).unwrap())
             .collect())
     }
 
@@ -283,7 +282,7 @@ fn main() {
 
     #[pymodule]
     /// A Python module implemented in Rust.
-    fn portmod(_: Python, m: &PyModule) -> PyResult<()> {
+    fn portmod(py: Python, m: &PyModule) -> PyResult<()> {
         m.add_wrapped(wrap_pyfunction!(get_masters))?;
         m.add_wrapped(wrap_pyfunction!(dds_dimensions))?;
         m.add_wrapped(wrap_pyfunction!(parse_package_metadata))?;
@@ -305,6 +304,21 @@ fn main() {
         m.add_class::<News>()?;
         m.add_class::<index::PackageIndexData>()?;
 
+        let submodule = PyModule::new(py, "directories")?;
+        let user_dirs: UserDirs = UserDirs::new().ok_or_else(|| {
+            PyErr::new::<PyFileNotFoundError, _>("No valid home directory path was found!")
+        })?;
+        let project_dirs: ProjectDirs =
+            ProjectDirs::from("", "portmod", "portmod").ok_or_else(|| {
+                PyErr::new::<PyFileNotFoundError, _>("No valid home directory path was found!")
+            })?;
+
+        submodule.add("download_dir", user_dirs.download_dir())?;
+        submodule.add("cache_dir", project_dirs.cache_dir())?;
+        submodule.add("data_dir", project_dirs.data_dir())?;
+        submodule.add("config_dir", project_dirs.preference_dir())?;
+        m.add_submodule(submodule)?;
+
         Ok(())
     }
 
