@@ -10,7 +10,7 @@ import shutil
 import sys
 from locale import LC_ALL, setlocale
 from logging import error
-from tempfile import gettempdir
+from tempfile import mkdtemp
 from types import SimpleNamespace
 from typing import Any, Dict, Optional
 
@@ -41,14 +41,9 @@ def set_test_repo():
         print("[test]", file=file)
         print(f"location = {TEST_REPO.location}", file=file)
         print("auto_sync = False", file=file)
-    set_config_value("REPOS", "test")
 
 
-def setup_env(profile, directory: Optional[str] = None):
-    """
-    Sets up an entire testing environment
-    All file writes will occur within a temporary directory as a result
-    """
+def setup_no_prefix():
     global OLD, OLD_CWD, TESTDIR
     # Use C locale. This will fail to read files containing unicode,
     # unless the files are supposed to and we explicitly open them as utf-8
@@ -60,21 +55,40 @@ def setup_env(profile, directory: Optional[str] = None):
     clear_install_cache()
     OLD = env.__dict__
     OLD_CWD = cwd
-    TESTDIR = os.path.join(gettempdir(), "portmod.test")
+    TESTDIR = mkdtemp(prefix="portmod.test")
     env.CONFIG_DIR = os.path.join(TESTDIR, "config")
     env.CACHE_DIR = os.path.join(TESTDIR, "cache")
     env.DATA_DIR = os.path.join(TESTDIR, "local")
     env.INTERACTIVE = False
     env.TESTING = True
     env.DEBUG = True
+    env.PREFIX_NAME = None
+
+    os.makedirs(TESTDIR, exist_ok=True)
+    os.makedirs(os.path.join(TESTDIR, "local"), exist_ok=True)
+    os.makedirs(os.path.join(TESTDIR, "work"), exist_ok=True)
+    os.chdir(os.path.join(TESTDIR, "work"))
 
     refresh_env()
+    set_test_repo()
+    refresh_env()
+
+
+def setup_env(profile, directory: Optional[str] = None):
+    """
+    Sets up an entire testing environment
+    All file writes will occur within a temporary directory as a result
+    """
+    global TESTDIR
+    setup_no_prefix()
+    assert TESTDIR
     if "test" not in get_prefixes():
         add_prefix("test", "test", directory)
     env.set_prefix("test")
     select_profile(profile)
-    set_test_repo()
     refresh_env()
+    if env.PREFIX_NAME is not None:
+        set_config_value("REPOS", "test")
 
     with VDB() as gitrepo:
         gitrepo.config_writer().set_value("commit", "gpgsign", False).release()
@@ -82,10 +96,7 @@ def setup_env(profile, directory: Optional[str] = None):
             "user", "email", "pytest@example.com"
         ).release()
         gitrepo.config_writer().set_value("user", "name", "pytest").release()
-    os.makedirs(TESTDIR, exist_ok=True)
-    os.makedirs(os.path.join(TESTDIR, "local"), exist_ok=True)
-    os.makedirs(os.path.join(TESTDIR, "work"), exist_ok=True)
-    os.chdir(os.path.join(TESTDIR, "work"))
+
     sync([TEST_REPO])
     return {
         "testdir": TESTDIR,
