@@ -20,4 +20,5 @@ def setup():
 
 def test_common_install():
     """Tests that packages with common dependencies install correctly"""
-    configure(["test/test-new"], no_confirm=True)
+    configure(["test/test-new"])
+    configure(["test/test-new"], depclean=True)
