@@ -15,6 +15,7 @@ from portmod.globals import env
 from portmod.loader import load_file
 from portmod.package import install_pkg
 from portmod.repo import Repo
+from portmodlib._deprecated import _get_install_dir_dest
 from portmodlib.fs import get_hash
 
 from .env import setup_env, tear_down_env
@@ -80,7 +81,7 @@ class Package(Pybuild1):
     mod = load_file(file)
     install_pkg(mod, set())
 
-    base = os.path.join(env.prefix().ROOT, mod._get_install_dir_dest())
+    base = os.path.join(env.prefix().ROOT, _get_install_dir_dest(mod))
     whitelisted = LISTED.copy()
     for root, _, files in os.walk(base):
         for file in files:
@@ -121,7 +122,7 @@ class Package(Pybuild1):
 
     other_files = OTHER.copy()
 
-    base = os.path.join(env.prefix().ROOT, mod._get_install_dir_dest())
+    base = os.path.join(env.prefix().ROOT, _get_install_dir_dest(mod))
     for root, _, files in os.walk(base):
         for file in files:
             path = os.path.relpath(root, base)
