@@ -11,7 +11,7 @@ from logging import error
 
 import pytest
 
-from portmod._cli.inquisitor import main, scan_file, scan_root
+from portmod._cli.inquisitor import main, scan_file, scan_root, scan_sources
 
 from .env import TEST_REPO, setup_env, tear_down_env
 
@@ -53,4 +53,24 @@ def test_inquisitor_main():
     main()
 
 
+def test_scan_sources():
+    has_error = False
+
+    def err(string: str):
+        nonlocal has_error
+        error(string)
+        has_error = True
+
+    scan_sources(
+        os.path.join(
+            TEST_REPO.location,
+            "test",
+            "quill-of-feyfolken",
+            "quill-of-feyfolken-2.0.2.pybuild",
+        ),
+        err,
+    )
+    assert not has_error, "Source should be available"
+
+
 # TODO: Add tests that modify the test repo to be invalid
