@@ -17,7 +17,7 @@ from portmod.repo import Repo
 from portmod.repo.loader import _safe_load_file
 from portmod.win32 import get_personal
 
-from .env import TEST_REPO_DIR, rmtree, setup_env, tear_down_env
+from .env import rmtree, setup_env, tear_down_env
 
 TMP_REPO = os.path.join(os.path.dirname(env.TMP_DIR), "not-portmod")
 TMP_VERSION = 0
@@ -49,22 +49,11 @@ def create_pybuild(filestring, manifest: bool = False):
     global TMP_VERSION, TMP_FILE
     TMP_VERSION += 1
     TMP_FILE = os.path.join(TMP_REPO, "test", "test", f"test-{TMP_VERSION}.pybuild")
-    if (
-        "{TMP_FILE}" in filestring
-        or "{BLOCKED_FILE}" in filestring
-        or "{TMP_DIR}" in filestring
-    ):
-        filestring = filestring.format(
-            TMP_FILE=TMP_FILE, BLOCKED_FILE=BLOCKED_FILE, TMP_DIR=env.TMP_DIR
-        )
     os.makedirs(env.TMP_DIR, exist_ok=True)
     os.makedirs(os.path.dirname(TMP_FILE), exist_ok=True)
     os.makedirs(os.path.join(TMP_REPO, "profiles"), exist_ok=True)
     clear_cache_for_path(TMP_FILE)
 
-    if sys.platform == "win32":
-        filestring = filestring.replace("\\", "\\\\")
-
     with open(TMP_FILE, "w") as file:
         file.write(filestring)
 
@@ -103,11 +92,11 @@ class Package(Pybuild1):
 
 def test_write_globalscope():
     """Tests that writing to files outside TMP_DIR is forbidden in the global scope"""
-    file = """
+    file = f"""
 import os
 from pybuild import Pybuild1
 
-os.remove("{TMP_FILE}")
+os.remove(r"{TMP_FILE}")
 
 class Package(Pybuild1):
     NAME="Test"
@@ -122,11 +111,11 @@ class Package(Pybuild1):
 
 def test_write_globalscope_2():
     """Tests that writing to files within TMP_DIR is forbidden in the global scope"""
-    file = """
+    file = f"""
 import os
 from pybuild import Pybuild1
 
-os.remove("{TMP_DIR}")
+os.remove(r"{TMP_FILE}")
 
 class Package(Pybuild1):
     NAME="Test"
@@ -141,11 +130,11 @@ class Package(Pybuild1):
 
 def test_read_globalscope():
     """Tests that reading from files outside TMP_DIR is forbidden in the global scope"""
-    file = """
+    file = f"""
 import os
 from pybuild import Pybuild1
 
-assert os.path.exists("{BLOCKED_FILE}")
+assert os.path.exists(r"{BLOCKED_FILE}")
 
 class Package(Pybuild1):
     NAME="Test"
@@ -160,7 +149,7 @@ class Package(Pybuild1):
 
 def test_read_src_unpack():
     """Tests that reading from files outside TMP_DIR is forbidden within src_unpack"""
-    file = """
+    file = f"""
 import os
 from pybuild import Pybuild1
 
@@ -171,7 +160,7 @@ class Package(Pybuild1):
     LICENSE="GPL-3"
 
     def src_unpack(self):
-        assert os.path.exists("{BLOCKED_FILE}")
+        assert os.path.exists(r"{BLOCKED_FILE}")
 """
     create_pybuild(file)
     mod = load_file(TMP_FILE)
@@ -179,14 +168,9 @@ class Package(Pybuild1):
         src_unpack(mod, env.TMP_DIR)
 
 
-@pytest.mark.xfail(
-    sys.platform == "win32",
-    reason="Sandboxie's permissions don't allow nesting, so we have to use the "
-    "default redirected writes, which don't raise exceptions",
-)
 def test_write_src_unpack():
     """Tests that writing to files outside TMP_DIR is forbidden within src_unpack"""
-    file = """
+    file = f"""
 import os
 from pybuild import Pybuild1
 
@@ -197,12 +181,17 @@ class Package(Pybuild1):
     LICENSE="GPL-3"
 
     def src_unpack(self):
-        os.remove("{TMP_FILE}")
+        os.remove(r"{TMP_FILE}")
 """
     create_pybuild(file)
     mod = load_file(TMP_FILE)
-    with pytest.raises(SandboxedError):
+    if sys.platform == "win32":
+        # Sandboxie's permissions don't allow nesting, so we have to use the
+        # default redirected writes, which don't raise exceptions
         src_unpack(mod, env.TMP_DIR)
+    else:
+        with pytest.raises(SandboxedError):
+            src_unpack(mod, env.TMP_DIR)
     assert os.path.exists(TMP_FILE)
 
 
@@ -210,7 +199,7 @@ def test_read_can_update_live():
     """
     Tests that reading from files outside TMP_DIR is forbidden within can_update_live
     """
-    file = """
+    file = f"""
 import os
 from pybuild import Pybuild1
 
@@ -221,7 +210,7 @@ class Package(Pybuild1):
     LICENSE="GPL-3"
 
     def can_update_live(self):
-        assert os.path.exists("{BLOCKED_FILE}")
+        assert os.path.exists(r"{BLOCKED_FILE}")
         return True
 """
     create_pybuild(file)
@@ -230,16 +219,11 @@ class Package(Pybuild1):
         _sandbox_execute_pybuild(mod.FILE, "can-update-live", Permissions(network=True))
 
 
-@pytest.mark.xfail(
-    sys.platform == "win32",
-    reason="Sandboxie's permissions don't allow nesting, so we have to use the "
-    "default redirected writes, which don't raise exceptions",
-)
 def test_write_can_update_live():
     """
     Tests that writing to files outside TMP_DIR is forbidden within can_update_live
     """
-    file = """
+    file = f"""
 import os
 from pybuild import Pybuild1
 
@@ -250,19 +234,26 @@ class Package(Pybuild1):
     LICENSE="GPL-3"
 
     def can_update_live(self):
-        os.remove("{TMP_FILE}")
+        os.remove(r"{TMP_FILE}")
         return True
 """
     create_pybuild(file)
     mod = load_file(TMP_FILE)
-    with pytest.raises(SandboxedError):
+    if sys.platform == "win32":
+        # Sandboxie's permissions don't allow nesting, so we have to use the
+        # default redirected writes, which don't raise exceptions
         _sandbox_execute_pybuild(mod.FILE, "can-update-live", Permissions(network=True))
+    else:
+        with pytest.raises(SandboxedError):
+            _sandbox_execute_pybuild(
+                mod.FILE, "can-update-live", Permissions(network=True)
+            )
     assert os.path.exists(TMP_FILE)
 
 
 def test_read_src_prepare():
     """Tests that reading from files outside TMP_DIR is allowed within src_prepare"""
-    file = """
+    file = f"""
 import os
 from pybuild import Pybuild1
 
@@ -273,21 +264,16 @@ class Package(Pybuild1):
     LICENSE="GPL-3"
 
     def src_prepare(self):
-        assert os.path.exists("{BLOCKED_FILE}")
+        assert os.path.exists(r"{BLOCKED_FILE}")
 """
     create_pybuild(file)
     mod = load_file(TMP_FILE)
     src_prepare(mod, env.TMP_DIR)
 
 
-@pytest.mark.xfail(
-    sys.platform == "win32",
-    reason="Sandboxie's permissions don't allow nesting, so we have to use the "
-    "default redirected writes, which don't raise exceptions",
-)
 def test_write_src_prepare():
     """Tests that writing to files outside TMP_DIR is not allowed within src_prepare"""
-    file = """
+    file = f"""
 import os
 from pybuild import Pybuild1
 
@@ -298,12 +284,17 @@ class Package(Pybuild1):
     LICENSE="GPL-3"
 
     def src_prepare(self):
-        os.remove("{TMP_FILE}")
+        os.remove(r"{TMP_FILE}")
 """
     create_pybuild(file)
     mod = load_file(TMP_FILE)
-    with pytest.raises(SandboxedError):
+    if sys.platform == "win32":
+        # Sandboxie's permissions don't allow nesting, so we have to use the
+        # default redirected writes, which don't raise exceptions
         src_prepare(mod, env.TMP_DIR)
+    else:
+        with pytest.raises(SandboxedError):
+            src_prepare(mod, env.TMP_DIR)
     assert os.path.exists(TMP_FILE)
 
 
@@ -455,7 +446,7 @@ class Package(Pybuild1):
         sys.platform = "foo"
 
         if origplatform == "win32":
-            self.execute("dir")
+            self.execute("cmd /c dir")
         else:
             self.execute("ls")
 """
@@ -466,7 +457,7 @@ class Package(Pybuild1):
 
 def test_execute_src_prepare_write():
     """Tests that we can't modify files through execute in src_prepare"""
-    file = """
+    file = f"""
 from pybuild import Pybuild1
 import sys
 
@@ -482,9 +473,9 @@ class Package(Pybuild1):
         origplatform = sys.platform
         sys.platform = "foo"
         if origplatform == "win32":
-            self.execute('cmd /c "del {TMP_FILE}"')
+            self.execute(r'cmd /c "del {TMP_FILE}"')
         else:
-            self.execute("rm {TMP_FILE}")
+            self.execute(r"rm {TMP_FILE}")
 """
     create_pybuild(file)
     mod = load_file(TMP_FILE)
@@ -499,7 +490,7 @@ class Package(Pybuild1):
 
 def test_execute_src_prepare_read():
     """Tests that we can read files through execute in src_prepare"""
-    file = """
+    file = f"""
 from pybuild import Pybuild1
 import sys
 
@@ -516,9 +507,9 @@ class Package(Pybuild1):
         sys.platform = "foo"
 
         if origplatform == "win32":
-            self.execute('dir "{BLOCKED_FILE}"')
+            self.execute(r'cmd /c dir "{BLOCKED_FILE}"')
         else:
-            self.execute("ls {BLOCKED_FILE}")
+            self.execute(r"ls {BLOCKED_FILE}")
 """
     create_pybuild(file)
     mod = load_file(TMP_FILE)
@@ -527,7 +518,7 @@ class Package(Pybuild1):
 
 def test_execute_src_unpack_read():
     """Tests that we can't read files through execute in src_unpack"""
-    file = """
+    file = f"""
 from pybuild import Pybuild1
 import sys
 
@@ -543,9 +534,9 @@ class Package(Pybuild1):
         origplatform = sys.platform
         sys.platform = "foo"
         if origplatform == "win32":
-            self.execute('dir "{BLOCKED_FILE}"')
+            self.execute(r'cmd /c dir "{BLOCKED_FILE}"')
         else:
-            self.execute("ls {BLOCKED_FILE}")
+            self.execute(r"ls {BLOCKED_FILE}")
 """
     create_pybuild(file)
     mod = load_file(TMP_FILE)
@@ -585,7 +576,7 @@ class Package(Pybuild1):
 
 def test_execute_permissions_bleed():
     """Tests that network permissions from src_unpack don't bleed into src_prepare"""
-    file = """
+    file = f"""
 from pybuild import Pybuild1
 import sys
 
@@ -596,9 +587,9 @@ class Package(Pybuild1):
 
     def src_unpack(self):
         if sys.platform == "win32":
-            self.execute('dir "{TMP_DIR}"')
+            self.execute(r'cmd /c dir "{env.TMP_DIR}"')
         else:
-            self.execute("ls {TMP_DIR}")
+            self.execute(r"ls {env.TMP_DIR}")
 
     def src_prepare(self):
         if sys.platform == "win32":
@@ -635,7 +626,7 @@ class Package(Pybuild1):
 
 def test_execute_escape():
     """Tests that you can't escape from execute"""
-    file = """
+    file = f"""
 from pybuild import Pybuild1
 import sys
 
@@ -647,9 +638,9 @@ class Package(Pybuild1):
 
     def src_prepare(self):
         if sys.platform == "win32":
-            self.execute('& del "{TMP_FILE}"')
+            self.execute(r'& del "{TMP_FILE}"')
         else:
-            self.execute("; rm {TMP_FILE}")
+            self.execute(r"; rm {TMP_FILE}")
 """
     create_pybuild(file)
     mod = load_file(TMP_FILE)
@@ -660,7 +651,7 @@ class Package(Pybuild1):
 
 def test_execute_escape_2():
     """Tests that you can't escape from execute"""
-    file = """
+    file = f"""
 from pybuild import Pybuild1
 import sys
 
@@ -672,9 +663,9 @@ class Package(Pybuild1):
 
     def src_prepare(self):
         if sys.platform == "win32":
-            self.execute('"& cmd /c "del {TMP_FILE}"')
+            self.execute(r'"& cmd /c "del {TMP_FILE}"')
         else:
-            self.execute("; rm {TMP_FILE}")
+            self.execute(r"; rm {TMP_FILE}")
 """
     create_pybuild(file)
     mod = load_file(TMP_FILE)
@@ -685,7 +676,7 @@ class Package(Pybuild1):
 
 def test_safe_open_src_unpack():
     """Tests that you can't use open in src_unpack"""
-    file = """
+    file = f"""
 from pybuild import Pybuild1
 
 
@@ -695,7 +686,7 @@ class Package(Pybuild1):
     LICENSE="GPL-3"
 
     def src_unpack(self):
-        with open("{BLOCKED_FILE}", "r") as file:
+        with open(r"{BLOCKED_FILE}", "r") as file:
             file.read()
 """
     create_pybuild(file)
@@ -704,14 +695,9 @@ class Package(Pybuild1):
         src_unpack(mod, env.TMP_DIR)
 
 
-@pytest.mark.xfail(
-    sys.platform == "win32",
-    reason="Sandboxie's permissions don't allow nesting, so we have to use the "
-    "default redirected writes, which don't raise exceptions",
-)
 def test_safe_open_src_prepare():
     """Tests that you can't write outside tmpdir with open in src_prepare"""
-    file = """
+    file = f"""
 from pybuild import Pybuild1
 
 
@@ -721,18 +707,25 @@ class Package(Pybuild1):
     LICENSE="GPL-3"
 
     def src_prepare(self):
-        with open("{TMP_FILE}", "w") as file:
+        with open(r"{TMP_FILE}", "w") as file:
             print("foo", file=file)
 """
     create_pybuild(file)
     mod = load_file(TMP_FILE)
-    with pytest.raises(SandboxedError):
+    if sys.platform == "win32":
+        # Sandboxie's permissions don't allow nesting, so we have to use the
+        # default redirected writes, which don't raise exceptions
         src_prepare(mod, env.TMP_DIR)
+    else:
+        with pytest.raises(SandboxedError):
+            src_prepare(mod, env.TMP_DIR)
+    with open(TMP_FILE) as fs_file:
+        assert not fs_file.read().startswith("foo")
 
 
 def test_safe_open_allowed():
     """Tests situations where you can use open"""
-    file = """
+    file = f"""
 from pybuild import Pybuild1
 
 class Package(Pybuild1):
@@ -741,13 +734,13 @@ class Package(Pybuild1):
     LICENSE="GPL-3"
 
     def src_prepare(self):
-        with open("{BLOCKED_FILE}", "r") as file:
+        with open(r"{BLOCKED_FILE}", "r") as file:
             file.read()
-        with open("{TMP_DIR}/foofile", "w") as file:
+        with open(r"{env.TMP_DIR}/foofile", "w") as file:
             print("foo", file=file)
 
     def src_unpack(self):
-        with open("{TMP_DIR}/foofile", "w") as file:
+        with open(r"{env.TMP_DIR}/foofile", "w") as file:
             print("foo", file=file)
 """
     create_pybuild(file)
@@ -833,14 +826,6 @@ class Package(Pybuild1):
     src_unpack(mod, env.TMP_DIR)
 
 
-def test_loader():
-    _sandbox_execute_pybuild(
-        os.path.join(TEST_REPO_DIR, "test/test/test-1.0.pybuild"),
-        "cache",
-        Permissions(),
-    )
-
-
 def test_inplacevar():
     """Tests that inplace modification of variables works"""
     file = """
@@ -967,7 +952,7 @@ class Package(Pybuild1):
             )
             version = read_reg(
                 HKEY_LOCAL_MACHINE,
-                "SOFTWARE\\Microsoft\\Windows\\CurrentVersion"
+                r"SOFTWARE\\Microsoft\\Windows\\CurrentVersion"
             )
             assert version is not None
 """
