@@ -5,7 +5,6 @@
 Tests modifying user use flags
 """
 
-import os
 import sys
 from io import StringIO
 
@@ -31,10 +30,6 @@ def setup():
     tear_down_env()
 
 
-@pytest.mark.skipif(
-    sys.platform == "win32" and "APPVEYOR" in os.environ,
-    reason="Windows CI is flaky with deleting git repositories",
-)
 def test_logging():
     """Tests that verbose and quiet control output verbosity"""
     oldargs = sys.argv
