@@ -8,6 +8,7 @@ import pytest
 from portmod._deps import DepError, resolve
 from portmod.config.mask import get_masked, get_unmasked, is_masked
 from portmod.globals import env
+from portmod.loader import load_pkg
 from portmod.transactions import New
 from portmodlib.atom import Atom, atom_sat
 
@@ -58,3 +59,21 @@ def test_unmask(setup):
     assert len(transactions.pkgs) == 1
     assert isinstance(transactions.pkgs[0], New)
     assert atom_sat(transactions.pkgs[0].pkg.ATOM, Atom("=test/test-1.0"))
+
+
+def test_profile_mask(setup):
+    """Tests that masked packages in the profile prevents them from being installed"""
+    selected = {Atom("=test/masked-1.1")}
+
+    with pytest.raises(DepError):
+        resolve(selected, set(), selected, selected, set())
+
+
+def test_common_mask(setup):
+    """Tests that masked common packages prevents installation but not loading"""
+    selected = {Atom("=test/masked-1.0")}
+
+    assert load_pkg(Atom("=test/masked-1.0"))
+
+    with pytest.raises(DepError):
+        resolve(selected, set(), selected, selected, set())
