@@ -9,7 +9,7 @@ import pytest
 from portmod._cli.main import main
 from portmod.globals import env
 from portmod.merge import configure
-from portmod.modules import get_redirections
+from portmod.modules import get_redirections, iterate_modules
 
 from .env import setup_env, tear_down_env
 
@@ -27,15 +27,26 @@ def setup():
 
 def test_module(setup):
     """Tests that modules work as expected"""
-    configure(["test/test-module"])
+    configure(["test/test-module"], oneshot=True)
     assert os.path.exists(
         os.path.join(env.prefix().CONFIG_PROTECT_DIR, "foo.cfg_protect")
     )
     assert get_redirections()
 
 
+def test_module_params(setup):
+    configure(["test/test-module"], oneshot=True)
+    for module in iterate_modules():
+        module_function = module.funcs.get("add")
+        assert module_function
+        assert module_function.name == "add"
+        assert module_function.desc == "Add to list"
+        assert module_function.options == ["item"]
+        assert module_function.parameters == ["item to add to the list"]
+
+
 def test_module_cli(setup):
     """Tests that the CLI module interface works"""
-    configure(["test/test-module"])
+    configure(["test/test-module"], oneshot=True)
     sys.argv = ["portmod", "test", "select", "test-module", "list"]
     main()
