@@ -5,9 +5,11 @@
 Portmod config tests
 """
 
+import os
+
 import pytest
 
-from portmod.config import get_config
+from portmod.config import get_config, set_config_value
 from portmod.globals import env
 
 from .env import setup_env, tear_down_env
@@ -62,3 +64,28 @@ TEST_PROFILE_ONLY = "BAR"
     get_config.cache_clear()
     with pytest.raises(UserWarning):
         get_config()
+
+
+def test_set_config_value():
+    def test():
+        set_config_value("foo", "1")
+        assert get_config()["foo"] == "1"
+
+    # Test with other variable
+    with open(env.prefix().CONFIG, "w") as file:
+        file.write('bar = "baz"')
+    test()
+
+    # Test with just comment
+    with open(env.prefix().CONFIG, "w") as file:
+        file.write("# Comment")
+    test()
+
+    # Test with empty file
+    with open(env.prefix().CONFIG, "w"):
+        pass
+    test()
+
+    # Test with nonexistant file
+    os.remove(env.prefix().CONFIG)
+    test()
