@@ -66,5 +66,5 @@ def test_use():
 
 def test_mirror():
     """Tests that portmod --version works correctly"""
-    sys.argv = ["portmod", "mirror", os.path.join(env.TMP_DIR, "mirror")]
+    sys.argv = ["portmod", "mirror", os.path.join(env.TMP_DIR, "mirror"), "test"]
     main()
