@@ -9,9 +9,9 @@ from pathlib import Path
 
 import pytest
 
+from portmod.config.profiles import get_profile_path, get_system, profile_parents
 from portmod.loader import load_all_installed
 from portmod.merge import configure
-from portmod.repo.profiles import get_profile_path, get_system, profile_parents
 
 from .env import setup_env, tear_down_env, unset_profile
 
@@ -46,7 +46,7 @@ def test_system(setup_repo):
     assert "test/test" in system
 
     assert not list(load_all_installed())
-    configure(["@world"], update=True, no_confirm=True)
+    configure(["@world"], update=True)
     mods = list(load_all_installed())
     assert len(mods) == len(system)
     for mod in mods:
