@@ -5,30 +5,33 @@
 Tests the version comparison system
 """
 
-from portmod.util import get_max_version
-from portmodlib.atom import version_gt
+import pytest
+
+from portmodlib.atom import Version
 
 
 def test_simple_version():
     """Tests extremely simple version comparison"""
     v_b = "2.0"
     v_a = "1.0"
-    assert get_max_version([v_a, v_b]) == v_b
+    assert max([v_a, v_b]) == v_b
 
 
-def gt(atom1, atom2):
-    """Tests that atom1 is considered greater than atom2"""
-    assert version_gt(atom1, atom2)
-    assert not version_gt(atom2, atom1)
-    assert get_max_version([atom1, atom2]) == atom1
-    assert get_max_version([atom2, atom1]) == atom1
+def gt(ver1, ver2):
+    """Tests that ver1 is considered greater than ver2"""
+    ver1 = Version(ver1)
+    ver2 = Version(ver2)
+    assert ver1 > ver2
+    assert not ver2 > ver1
+    assert max([ver1, ver2]) == ver1
+    assert max([ver2, ver1]) == ver1
 
 
 def test_suffix():
     """Tests that suffixed versions come before full versions"""
-    assert (
-        get_max_version(["2.0_alpha", "2.0_beta", "2.0_pre", "2.0_rc", "2.0"]) == "2.0"
-    )
+    assert max(
+        map(Version, ["2.0_alpha", "2.0_beta", "2.0_pre", "2.0_rc", "2.0"])
+    ) == Version("2.0")
 
 
 def test_suffix_p():
@@ -75,3 +78,38 @@ def test_different_version_lengths():
     gt("2.0.1", "2.0")
     gt("2.1", "2.0.1")
     gt("2.0.1_alpha", "2.0_p1-r1")
+
+
+def test_different_epochs():
+    """
+    Tests that packages with a larger epoch are considered a greater version
+    """
+    gt("e1-2.0", "2.0")
+    gt("e1-0.1", "2.0")
+    gt("e2-0.1", "e1-2.0.0")
+    gt("e1-2.1", "e1-2")
+
+
+def test_leading_zeroes():
+    """
+    Tests that versions with leading zeroes are compared lexicographically
+    """
+    gt("2.1", "2.01")
+    gt("2.10", "2.9")
+    gt("2.1", "2.09")
+    gt("2", "1.09")
+    gt("2.09", "2")
+
+
+def test_invalid():
+    """
+    Tests that invalid versions do not parse
+    """
+    with pytest.raises(TypeError):
+        Version("1.")
+
+    with pytest.raises(TypeError):
+        Version("1.0-2")
+
+    with pytest.raises(TypeError):
+        Version("1.a")
