@@ -47,8 +47,8 @@ def setup():
     with open(env.prefix().CONFIG, "w") as configfile:
         print(
             f"""
-TEST_CONFIG = "{config}"
-TEST_CONFIG_INI = "{config_ini}"
+TEST_CONFIG = r"{config}"
+TEST_CONFIG_INI = r"{config_ini}"
 """,
             file=configfile,
         )
